#
import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats import resolve_arabic_category_label

data1 = {
    "Category:Cultural depictions of American men": "تصنيف:تصوير ثقافي عن رجال أمريكيين",
    "Category:Cultural depictions of American people": "تصنيف:التصوير الثقافي للأمريكيين",
    "Category:Cultural depictions of Argentine men": "تصنيف:تصوير ثقافي عن رجال أرجنتينيين",
    "Category:Cultural depictions of Argentine people": "تصنيف:تصوير ثقافي عن أرجنتينيين",
    "Category:Cultural depictions of Assyrian people": "تصنيف:تصوير ثقافي عن آشوريين",
    "Category:Cultural depictions of Australian men": "تصنيف:تصوير ثقافي عن رجال أستراليين",
    "Category:Cultural depictions of Australian people": "تصنيف:تصوير ثقافي عن أستراليين",
    "Category:Cultural depictions of Austrian men": "تصنيف:تصوير ثقافي عن رجال نمساويين",
    "Category:Cultural depictions of Austrian people": "تصنيف:التصوير الثقافي للنمساويين",
    "Category:Cultural depictions of Bangladeshi people": "تصنيف:تصوير ثقافي عن أعلام بنغلاديشيين",
    "Category:Cultural depictions of Belgian men": "تصنيف:تصوير ثقافي عن رجال بلجيكيين",
    "Category:Cultural depictions of Belgian people": "تصنيف:تصوير ثقافي عن بلجيكيين",
    "Category:Cultural depictions of Bolivian men": "تصنيف:تصوير ثقافي عن رجال بوليفيين",
    "Category:Cultural depictions of Bolivian people": "تصنيف:تصوير ثقافي عن بوليفيين",
    "Category:Cultural depictions of Bosnia and Herzegovina people": "تصنيف:تصوير ثقافي عن بوسنيين",
    "Category:Cultural depictions of Brazilian people": "تصنيف:تصوير ثقافي عن برازيليين",
    "Category:Cultural depictions of British men": "تصنيف:تصوير ثقافي عن رجال بريطانيين",
    "Category:Cultural depictions of British people": "تصنيف:التصوير الثقافي للبريطانيين",
    "Category:Cultural depictions of Byzantine emperors": "تصنيف:تصوير ثقافي عن أباطرة بيزنطيين",
    "Category:Cultural depictions of Byzantine people": "تصنيف:تصوير ثقافي عن البيزنطيين",
    "Category:Cultural depictions of Canadian people": "تصنيف:تصوير ثقافي عن كنديين",
    "Category:Cultural depictions of Chilean people": "تصنيف:تصوير ثقافي عن تشيليين",
    "Category:Cultural depictions of Chinese men": "تصنيف:تصوير ثقافي عن رجال صينيين",
    "Category:Cultural depictions of Chinese monarchs": "تصنيف:تصوير ثقافي عن ملكيين صينيين",
    "Category:Cultural depictions of Chinese people": "تصنيف:تصوير ثقافي عن صينيين",
    "Category:Cultural depictions of Colombian people": "تصنيف:تصوير ثقافي لكولومبيين",
    "Category:Cultural depictions of Cuban people": "تصنيف:تصوير ثقافي لكوبيين",
    "Category:Cultural depictions of Czech people": "تصنيف:تصوير ثقافي عن تشيكيين",
    "Category:Cultural depictions of Danish monarchs": "تصنيف:تصوير ثقافي عن ملكيين دنماركيين",
    "Category:Cultural depictions of Danish people": "تصنيف:تصوير ثقافي عن دنماركيين",
    "Category:Cultural depictions of Dutch men": "تصنيف:تصوير ثقافي عن رجال هولنديين",
    "Category:Cultural depictions of Dutch people": "تصنيف:تصوير ثقافي لهولنديين",
    "Category:Cultural depictions of Egyptian men": "تصنيف:تصوير ثقافي لرجال مصريين",
    "Category:Cultural depictions of Egyptian people": "تصنيف:تصوير ثقافي لمصريين",
    "Category:Cultural depictions of Ethiopian people": "تصنيف:تصوير ثقافي عن إثيوبيين",
    "Category:Cultural depictions of Filipino people": "تصنيف:تصوير ثقافي عن الفلبينيين",
    "Category:Cultural depictions of French men": "تصنيف:تصوير ثقافي عن رجال فرنسيين",
    "Category:Cultural depictions of French people": "تصنيف:التصوير الثقافي للفرنسيين",
    "Category:Cultural depictions of Greek men": "تصنيف:تصوير ثقافي عن رجال يونانيين",
    "Category:Cultural depictions of Greek monarchs": "تصنيف:تصوير ثقافي عن ملكيين يونانيين",
    "Category:Cultural depictions of Greek people": "تصنيف:تصوير ثقافي ليونانيين",
    "Category:Cultural depictions of Hungarian men": "تصنيف:تصوير ثقافي عن رجال مجريين",
    "Category:Cultural depictions of Hungarian people": "تصنيف:تصوير ثقافي عن مجريين",
    "Category:Cultural depictions of Indian monarchs": "تصنيف:تصوير ثقافي عن ملكيين هنود",
    "Category:Cultural depictions of Iranian men": "تصنيف:تصوير ثقافي عن رجال إيرانيين",
    "Category:Cultural depictions of Iranian people": "تصنيف:تصوير ثقافي عن إيرانيين",
    "Category:Cultural depictions of Iraqi people": "تصنيف:تصوير ثقافي لعراقيين",
    "Category:Cultural depictions of Irish men": "تصنيف:تصوير ثقافي عن رجال أيرلنديين",
    "Category:Cultural depictions of Irish people": "تصنيف:تصوير ثقافي عن أيرلنديين",
    "Category:Cultural depictions of Israeli men": "تصنيف:تصوير ثقافي عن رجال إسرائيليين",
    "Category:Cultural depictions of Israeli people": "تصنيف:تصوير ثقافي للإسرائيليين",
    "Category:Cultural depictions of Italian men": "تصنيف:تصوير ثقافي عن رجال إيطاليين",
    "Category:Cultural depictions of Italian people": "تصنيف:تصوير ثقافي عن إيطاليين",
    "Category:Cultural depictions of Japanese men": "تصنيف:تصوير ثقافي عن رجال يابانيين",
    "Category:Cultural depictions of Japanese people": "تصنيف:التصوير الثقافي لليابانيين",
    "Category:Cultural depictions of Libyan people": "تصنيف:تصوير ثقافي لليبيين",
    "Category:Cultural depictions of Mexican men": "تصنيف:تصوير ثقافي عن رجال مكسيكيين",
    "Category:Cultural depictions of Mexican people": "تصنيف:تصوير ثقافي لمكسيكيين",
    "Category:Cultural depictions of Mongolian people": "تصنيف:تصوير ثقافي لمنغوليين",
    "Category:Cultural depictions of New Zealand people": "تصنيف:تصوير ثقافي عن نيوزيلنديين",
    "Category:Cultural depictions of North Korean people": "تصنيف:تصوير ثقافي عن كوريين شماليين",
    "Category:Cultural depictions of Norwegian men": "تصنيف:تصوير ثقافي عن رجال نرويجيين",
    "Category:Cultural depictions of Norwegian people": "تصنيف:تصوير ثقافي عن نرويجيين",
    "Category:Cultural depictions of Pakistani people": "تصنيف:تصوير ثقافي عن باكستانيين",
    "Category:Cultural depictions of Palestinian men": "تصنيف:تصوير ثقافي عن رجال فلسطينيين",
    "Category:Cultural depictions of Palestinian people": "تصنيف:تصوير ثقافي عن فلسطينيين",
    "Category:Cultural depictions of Polish men": "تصنيف:تصوير ثقافي عن رجال بولنديين",
    "Category:Cultural depictions of Polish people": "تصنيف:تصوير ثقافي لبولنديين",
    "Category:Cultural depictions of Portuguese people": "تصنيف:تصوير ثقافي عن البرتغاليين",
    "Category:Cultural depictions of Romanian people": "تصنيف:تصوير ثقافي عن رومانيين",
    "Category:Cultural depictions of Saudi Arabian men": "تصنيف:تصوير ثقافي عن رجال سعوديين",
    "Category:Cultural depictions of Saudi Arabian people": "تصنيف:تصوير ثقافي لسعوديين",
    "Category:Cultural depictions of Scottish men": "تصنيف:تصوير ثقافي عن رجال إسكتلنديين",
    "Category:Cultural depictions of Scottish people": "تصنيف:تصوير ثقافي عن إسكتلنديين",
    "Category:Cultural depictions of Serbian monarchs": "تصنيف:تصوير ثقافي عن ملكيين صرب",
    "Category:Cultural depictions of South Korean people": "تصنيف:تصوير ثقافي عن كوريين جنوبيين",
    "Category:Cultural depictions of Sri Lankan people": "تصنيف:تصوير ثقافي عن أعلام سريلانكيين",
    "Category:Cultural depictions of Swedish men": "تصنيف:تصوير ثقافي عن رجال سويديين",
    "Category:Cultural depictions of Swedish people": "تصنيف:تصوير ثقافي عن سويديين",
    "Category:Cultural depictions of Swiss men": "تصنيف:تصوير ثقافي عن رجال سويسريين",
    "Category:Cultural depictions of Swiss people": "تصنيف:تصوير ثقافي عن سويسريين",
    "Category:Cultural depictions of Thai people": "تصنيف:تصوير ثقافي عن تايلنديين",
    "Category:Cultural depictions of Ugandan people": "تصنيف:تصوير ثقافي عن أوغنديين",
    "Category:Cultural depictions of Ukrainian men": "تصنيف:تصوير ثقافي عن رجال أوكرانيين",
    "Category:Cultural depictions of Ukrainian people": "تصنيف:تصوير ثقافي لأوكرانيين",
    "Category:Cultural depictions of Uruguayan people": "تصنيف:تصوير ثقافي عن أوروغويانيين",
    "Category:Cultural depictions of Venezuelan people": "تصنيف:تصوير ثقافي عن فنزويليين",
    "Category:Cultural depictions of Welsh men": "تصنيف:تصوير ثقافي عن رجال ويلزيين",
    "Category:Cultural depictions of Welsh people": "تصنيف:تصوير ثقافي عن ويلزيين",
    "Category:Cultural depictions of Yugoslav people": "تصنيف:تصوير ثقافي عن يوغسلافيين",
    "Category:Cultural depictions of ancient Greek people": "تصنيف:تصوير ثقافي ليونانيين قدماء",
    "Category:Cultural depictions of architects": "تصنيف:تصوير ثقافي لمعماريين",
    "Category:Cultural depictions of astronomers": "تصنيف:تصوير ثقافي عن فلكيين",
    "Category:Cultural depictions of chemists": "تصنيف:تصوير ثقافي عن كيميائيين",
    "Category:Cultural depictions of comedians": "تصنيف:تصوير ثقافي لكوميديين",
    "Category:Cultural depictions of diplomats": "تصنيف:تصوير ثقافي عن دبلوماسيين",
    "Category:Cultural depictions of economists": "تصنيف:تصوير ثقافي لاقتصاديين",
    "Category:Cultural depictions of journalists": "تصنيف:تصوير ثقافي لصحفيين",
    "Category:Cultural depictions of male monarchs": "تصنيف:تصوير ثقافي عن ملكيين ذكور",
    "Category:Cultural depictions of mathematicians": "تصنيف:تصوير ثقافي عن رياضياتيين",
    "Category:Cultural depictions of military officers": "تصنيف:تصوير ثقافي لضباط عسكريين",
    "Category:Cultural depictions of monarchs": "تصنيف:تصوير ثقافي عن ملكيين",
    "Category:Cultural depictions of musicians": "تصنيف:التصوير الثقافي للموسيقيين",
    "Category:Cultural depictions of occultists": "تصنيف:تصوير ثقافي لغموضيين",
    "Category:Cultural depictions of physicists": "تصنيف:تصوير ثقافي عن فيزيائيين",
    "Category:Cultural depictions of politicians": "تصنيف:تصوير ثقافي لسياسيين",
    "Category:Cultural depictions of religious leaders": "تصنيف:تصوير ثقافي لقادة دينيين",
    "Category:Cultural depictions of sports-people": "تصنيف:تصوير ثقافي لرياضيين",
    "Category:Cultural depictions of the Maccabees": "تصنيف:تصوير ثقافي عن مكابيين",
}

fast_data = {
    "Category:Cultural depictions of Bulgarian people": "تصنيف:تصوير ثقافي عن بلغاريون",
    "Category:Cultural depictions of Cambodian people": "تصنيف:تصوير ثقافي عن كمبوديون",
    "Category:Cultural depictions of Canadian police officers": "تصنيف:تصوير ثقافي عن ضباط شرطة كنديون",
    "Category:Cultural depictions of Canadian politicians": "تصنيف:تصوير ثقافي عن سياسيون كنديون",
    "Category:Cultural depictions of 15th-century painters": "تصنيف:تصوير ثقافي عن رسامون في القرن 15",
    "Category:Cultural depictions of 16th-century painters": "تصنيف:تصوير ثقافي عن رسامون في القرن 16",
    "Category:Cultural depictions of 17th-century painters": "تصنيف:تصوير ثقافي عن رسامون في القرن 17",
    "Category:Cultural depictions of 18th-century painters": "تصنيف:تصوير ثقافي عن رسامون في القرن 18",
    "Category:Cultural depictions of 19th-century painters": "تصنيف:تصوير ثقافي عن رسامون في القرن 19",
    "Category:Cultural depictions of 20th-century painters": "تصنيف:تصوير ثقافي عن رسامون في القرن 20",
    "Category:Cultural depictions of Abraham Lincoln": "تصنيف:تصوير ثقافي عن أبراهام لينكون",
    "Category:Cultural depictions of Abu Bakr": "تصنيف:تصوير ثقافي عن أبو بكر الصديق",
    "Category:Cultural depictions of activists": "تصنيف:تصوير ثقافي عن ناشطون",
    "Category:Cultural depictions of actors": "تصنيف:تصوير ثقافي عن ممثلون",
    "Category:Cultural depictions of Adam Sandler": "تصنيف:تصوير ثقافي عن آدم ساندلر",
    "Category:Cultural depictions of Adam Smith": "تصنيف:تصوير ثقافي عن آدم سميث",
    "Category:Cultural depictions of admirals": "تصنيف:تصوير ثقافي عن أميرالات",
    "Category:Cultural depictions of Adolf Eichmann": "تصنيف:تصوير ثقافي عن أدولف آيخمان",
    "Category:Cultural depictions of Adolf Hitler": "تصنيف:تصوير ثقافي عن أدولف هتلر",
    "Category:Cultural depictions of Afghan people": "تصنيف:تصوير ثقافي عن أفغان",
    "Category:Cultural depictions of African-American people": "تصنيف:تصوير ثقافي عن أمريكيون أفارقة",
    "Category:Cultural depictions of Agatha Christie": "تصنيف:تصوير ثقافي عن أجاثا كريستي",
    "Category:Cultural depictions of Akbar": "تصنيف:تصوير ثقافي عن أكبر",
    "Category:Cultural depictions of Akhenaten": "تصنيف:تصوير ثقافي عن أخناتون",
    "Category:Cultural depictions of Alan Turing": "تصنيف:تصوير ثقافي عن آلان تورنغ",
    "Category:Cultural depictions of Albanian people": "تصنيف:تصوير ثقافي عن ألبان",
    "Category:Cultural depictions of Albert Einstein": "تصنيف:تصوير ثقافي عن ألبرت أينشتاين",
    "Category:Cultural depictions of Albert Speer": "تصنيف:تصوير ثقافي عن ألبرت شبير",
    "Category:Cultural depictions of Albrecht Dürer": "تصنيف:تصوير ثقافي عن آلبرخت دورر",
    "Category:Cultural depictions of Albrecht von Wallenstein": "تصنيف:تصوير ثقافي عن ألبرشت فون فالنشتاين",
    "Category:Cultural depictions of Al Capone": "تصنيف:تصوير ثقافي عن آل كابوني",
    "Category:Cultural depictions of Aleister Crowley": "تصنيف:تصوير ثقافي عن آليستر كراولي",
    "Category:Cultural depictions of Alexander Graham Bell": "تصنيف:تصوير ثقافي عن ألكسندر غراهام بل",
    "Category:Cultural depictions of Alexander Hamilton": "تصنيف:تصوير ثقافي عن ألكسندر هاميلتون",
    "Category:Cultural depictions of Alexander Pushkin": "تصنيف:تصوير ثقافي عن ألكسندر بوشكين",
    "Category:Cultural depictions of Alexander the Great": "تصنيف:تصوير ثقافي عن الإسكندر الأكبر",
    "Category:Cultural depictions of Alexios I Komnenos": "تصنيف:تصوير ثقافي عن ألكسيوس الأول كومنين",
    "Category:Cultural depictions of Alfred Hitchcock": "تصنيف:تصوير ثقافي عن ألفريد هتشكوك",
}

data_slow = {
    "Category:Cultural depictions of Alfred the Great": "تصنيف:تصوير ثقافي عن ألفريد العظيم",
    "Category:Cultural depictions of Al Gore": "تصنيف:تصوير ثقافي عن آل جور",
    "Category:Cultural depictions of Amelia Earhart": "تصنيف:تصوير ثقافي عن أميليا إيرهارت",
    "Category:Cultural depictions of American police officers": "تصنيف:تصوير ثقافي عن ضباط شرطة أمريكيون",
    "Category:Cultural depictions of American politicians": "تصنيف:تصوير ثقافي عن سياسيون أمريكيون",
    "Category:Cultural depictions of Amitabh Bachchan": "تصنيف:تصوير ثقافي عن أميتاب باتشان",
    "Category:Cultural depictions of Amy Winehouse": "تصنيف:تصوير ثقافي عن إيمي واينهاوس",
    "Category:Cultural depictions of ancient Egyptian people": "تصنيف:تصوير ثقافي عن أعلام مصريون قدماء",
    "Category:Cultural depictions of ancient Egyptian women": "تصنيف:تصوير ثقافي عن مصريات قدماء",
    "Category:Cultural depictions of ancient Greek women": "تصنيف:تصوير ثقافي عن يونانيات قديمات",
    "Category:Cultural depictions of ancient people": "تصنيف:تصوير ثقافي عن أشخاص قدماء",
    "Category:Cultural depictions of ancient Persian people": "تصنيف:تصوير ثقافي عن أعلام فرس قدماء",
    "Category:Cultural depictions of ancient Roman people": "تصنيف:تصوير ثقافي عن رومان قدماء",
    "Category:Cultural depictions of Andrew Jackson": "تصنيف:تصوير ثقافي عن أندرو جاكسون",
    "Category:Cultural depictions of Andrew Johnson": "تصنيف:تصوير ثقافي عن أندرو جونسون",
    "Category:Cultural depictions of Andy Kaufman": "تصنيف:تصوير ثقافي عن أندي كوفمان",
    "Category:Cultural depictions of Andy Warhol": "تصنيف:تصوير ثقافي عن آندي وارهول",
    "Category:Cultural depictions of Angela Merkel": "تصنيف:تصوير ثقافي عن أنغيلا ميركل",
    "Category:Cultural depictions of animals": "تصنيف:تصوير ثقافي عن حيوانات",
    "Category:Cultural depictions of Anna Nicole Smith": "تصنيف:تصوير ثقافي عن آنا نيكول سميث",
    "Category:Cultural depictions of Anne Boleyn": "تصنيف:تصوير ثقافي عن آن بولين",
    "Category:Cultural depictions of Anne Frank": "تصنيف:تصوير ثقافي عن آن فرانك",
    "Category:Cultural depictions of Anne of Cleves": "تصنيف:تصوير ثقافي عن آن من كليفز",
    "Category:Cultural depictions of Anne, Queen of Great Britain": "تصنيف:تصوير ثقافي عن آن (ملكة بريطانيا العظمى)",
    "Category:Cultural depictions of Anthony the Great": "تصنيف:تصوير ثقافي عن أنطونيوس الكبير",
    "Category:Cultural depictions of Anton Chekhov": "تصنيف:تصوير ثقافي عن أنطون تشيخوف",
    "Category:Cultural depictions of Antonio Vivaldi": "تصنيف:تصوير ثقافي عن أنطونيو فيفالدي",
    "Category:Cultural depictions of Anwar Sadat": "تصنيف:تصوير ثقافي عن محمد أنور السادات",
    "Category:Cultural depictions of Archimedes": "تصنيف:تصوير ثقافي عن أرخميدس",
    "Category:Cultural depictions of Aristotle": "تصنيف:تصوير ثقافي عن أرسطو",
    "Category:Cultural depictions of Armenian people": "تصنيف:تصوير ثقافي عن أرمن",
    "Category:Cultural depictions of Arminius": "تصنيف:تصوير ثقافي عن أرمينيوس",
    "Category:Cultural depictions of Arnold Schwarzenegger": "تصنيف:تصوير ثقافي عن أرنولد شوارزنيجر",
    "Category:Cultural depictions of Arthur Conan Doyle": "تصنيف:تصوير ثقافي عن آرثر كونان دويل",
    "Category:Cultural depictions of Arthur Rimbaud": "تصنيف:تصوير ثقافي عن آرثر رامبو",
    "Category:Cultural depictions of Arthur Wellesley, 1st Duke of Wellington": "تصنيف:تصوير ثقافي عن آرثر ويلزلي",
    "Category:Cultural depictions of Ashoka": "تصنيف:تصوير ثقافي عن أشوكا",
    "Category:Cultural depictions of assassins": "تصنيف:تصوير ثقافي عن منفذو اغتيالات",
    "Category:Cultural depictions of association football players": "تصنيف:تصوير ثقافي عن لاعبو كرة قدم",
    "Category:Cultural depictions of astronauts": "تصنيف:تصوير ثقافي عن رواد فضاء",
    "Category:Cultural depictions of Atal Bihari Vajpayee": "تصنيف:تصوير ثقافي عن أتال بيهاري فاجبايي",
    "Category:Cultural depictions of Auguste Rodin": "تصنيف:تصوير ثقافي عن أوغوست رودان",
    "Category:Cultural depictions of Augustine of Hippo": "تصنيف:تصوير ثقافي عن أوغسطينوس",
    "Category:Cultural depictions of August Strindberg": "تصنيف:تصوير ثقافي عن أوغست ستريندبرغ",
    "Category:Cultural depictions of Augustus": "تصنيف:تصوير ثقافي عن أغسطس (إمبراطور)",
    "Category:Cultural depictions of Aurelian": "تصنيف:تصوير ثقافي عن أوريليان",
    "Category:Cultural depictions of Austrian monarchs": "تصنيف:تصوير ثقافي عن ملكيون نمساويون",
    "Category:Cultural depictions of Averroes": "تصنيف:تصوير ثقافي عن ابن رشد",
    "Category:Cultural depictions of aviators": "تصنيف:تصوير ثقافي عن طيارون",
    "Category:Cultural depictions of Ayn Rand": "تصنيف:تصوير ثقافي عن آين راند",
    "Category:Cultural depictions of Ayrton Senna": "تصنيف:تصوير ثقافي عن آيرتون سينا",
    "Category:Cultural depictions of Babe Ruth": "تصنيف:تصوير ثقافي عن بيب روث",
    "Category:Cultural depictions of badminton players": "تصنيف:تصوير ثقافي عن لاعبو تنس ريشة",
    "Category:Cultural depictions of Barack Obama": "تصنيف:تصوير ثقافي عن باراك أوباما",
    "Category:Cultural depictions of Barbra Streisand": "تصنيف:تصوير ثقافي عن باربرا سترايساند",
    "Category:Cultural depictions of barons": "تصنيف:تصوير ثقافي عن بارونات",
    "Category:Cultural depictions of Baruch Spinoza": "تصنيف:تصوير ثقافي عن باروخ سبينوزا",
    "Category:Cultural depictions of baseball players": "تصنيف:تصوير ثقافي عن لاعبو كرة قاعدة",
    "Category:Cultural depictions of basketball players": "تصنيف:تصوير ثقافي عن لاعبو كرة سلة",
    "Category:Cultural depictions of Bayezid I": "تصنيف:تصوير ثقافي عن بايزيد الأول",
    "Category:Cultural depictions of Belshazzar": "تصنيف:تصوير ثقافي عن بلشاصر",
    "Category:Cultural depictions of Benedict Arnold": "تصنيف:تصوير ثقافي عن بينيديكت أرنولد",
    "Category:Cultural depictions of Benigno Aquino III": "تصنيف:تصوير ثقافي عن بنيغنو آكينو",
    "Category:Cultural depictions of Benito Juárez": "تصنيف:تصوير ثقافي عن بينيتو خواريز",
    "Category:Cultural depictions of Benito Mussolini": "تصنيف:تصوير ثقافي عن بينيتو موسوليني",
    "Category:Cultural depictions of Benjamin Disraeli": "تصنيف:تصوير ثقافي عن بينجامين دزرائيلي",
    "Category:Cultural depictions of Benjamin Franklin": "تصنيف:تصوير ثقافي عن بنجامين فرانكلين",
    "Category:Cultural depictions of Benjamin Netanyahu": "تصنيف:تصوير ثقافي عن بنيامين نتنياهو",
    "Category:Cultural depictions of Bertolt Brecht": "تصنيف:تصوير ثقافي عن برتولت بريشت",
    "Category:Cultural depictions of Betsy Ross": "تصنيف:تصوير ثقافي عن إليزابيث روس",
    "Category:Cultural depictions of Bette Davis": "تصنيف:تصوير ثقافي عن بيت ديفيس",
    "Category:Cultural depictions of Beyoncé": "تصنيف:تصوير ثقافي عن بيونسيه",
    "Category:Cultural depictions of biblical people": "تصنيف:تصوير ثقافي عن شخصيات الكتاب المقدس",
    "Category:Cultural depictions of Bill Clinton": "تصنيف:تصوير ثقافي عن بيل كلينتون",
    "Category:Cultural depictions of Bill Cosby": "تصنيف:تصوير ثقافي عن بيل كوسبي",
    "Category:Cultural depictions of Bill Gates": "تصنيف:تصوير ثقافي عن بيل غيتس",
    "Category:Cultural depictions of Billie Holiday": "تصنيف:تصوير ثقافي عن بيلي هوليدي",
    "Category:Cultural depictions of Billy the Kid": "تصنيف:تصوير ثقافي عن الولد بيلي",
    "Category:Cultural depictions of Bing Crosby": "تصنيف:تصوير ثقافي عن بينغ كروسبي",
    "Category:Cultural depictions of biologists": "تصنيف:تصوير ثقافي عن علماء أحياء",
    "Category:Cultural depictions of blues musicians": "تصنيف:تصوير ثقافي عن موسيقيو بلوز",
    "Category:Cultural depictions of Bobby Moore": "تصنيف:تصوير ثقافي عن بوبي مور",
    "Category:Cultural depictions of Bob Dylan": "تصنيف:تصوير ثقافي عن بوب ديلن",
    "Category:Cultural depictions of Bob Marley": "تصنيف:تصوير ثقافي عن بوب مارلي",
    "Category:Cultural depictions of bodybuilders": "تصنيف:تصوير ثقافي عن لاعبو كمال أجسام",
    "Category:Cultural depictions of Booker T. Washington": "تصنيف:تصوير ثقافي عن بوكر تي واشنطن",
    "Category:Cultural depictions of Boris Godunov": "تصنيف:تصوير ثقافي عن بوريس غودونوف",
    "Category:Cultural depictions of Boris Johnson": "تصنيف:تصوير ثقافي عن بوريس جونسون",
    "Category:Cultural depictions of Boris Yeltsin": "تصنيف:تصوير ثقافي عن بوريس يلتسن",
    "Category:Cultural depictions of Boudica": "تصنيف:تصوير ثقافي عن بوديكا",
    "Category:Cultural depictions of boxers": "تصنيف:تصوير ثقافي عن ملاكمون",
    "Category:Cultural depictions of B. R. Ambedkar": "تصنيف:تصوير ثقافي عن أمبيدكار",
    "Category:Cultural depictions of Brian Lara": "تصنيف:تصوير ثقافي عن بريان لارا",
    "Category:Cultural depictions of Brigham Young": "تصنيف:تصوير ثقافي عن بريغهام يونغ",
    "Category:Cultural depictions of Brigitte Bardot": "تصنيف:تصوير ثقافي عن بريجيت باردو",
    "Category:Cultural depictions of British monarchs": "تصنيف:تصوير ثقافي عن ملكيون بريطانيون",
    "Category:Cultural depictions of British police officers": "تصنيف:تصوير ثقافي عن ضباط شرطة بريطانيون",
    "Category:Cultural depictions of British politicians": "تصنيف:تصوير ثقافي عن سياسيون بريطانيون",
    "Category:Cultural depictions of Britney Spears": "تصنيف:تصوير ثقافي عن بريتني سبيرز",
    "Category:Cultural depictions of Bruce Lee": "تصنيف:تصوير ثقافي عن بروس لي",
    "Category:Cultural depictions of Buddy Holly": "تصنيف:تصوير ثقافي عن بودي هولي",
    "Category:Cultural depictions of Buffalo Bill": "تصنيف:تصوير ثقافي عن بافالو بيل",
    "Category:Cultural depictions of bullfighters": "تصنيف:تصوير ثقافي عن مصارعو ثيران",
    "Category:Cultural depictions of businesspeople": "تصنيف:تصوير ثقافي عن شخصيات أعمال",
    "Category:Cultural depictions of Buster Keaton": "تصنيف:تصوير ثقافي عن باستر كيتون",
    "Category:Cultural depictions of Buzz Aldrin": "تصنيف:تصوير ثقافي عن بز ألدرن",
    "Category:Cultural depictions of Caesarion": "تصنيف:تصوير ثقافي عن بطليموس الخامس عشر (قيصرون)",
    "Category:Cultural depictions of Caligula": "تصنيف:تصوير ثقافي عن كاليغولا",
    "Category:Cultural depictions of Calpurnia (wife of Caesar)": "تصنيف:تصوير ثقافي عن كالبورنيا",
    "Category:Cultural depictions of Calvin Coolidge": "تصنيف:تصوير ثقافي عن كالفين كوليدج",
    "Category:Cultural depictions of Camille Claudel": "تصنيف:تصوير ثقافي عن كاميل كلوديل",
    "Category:Cultural depictions of Caravaggio": "تصنيف:تصوير ثقافي عن كارافاجيو",
    "Category:Cultural depictions of Cardinal Mazarin": "تصنيف:تصوير ثقافي عن جول مازاران",
    "Category:Cultural depictions of Carl Gustaf Emil Mannerheim": "تصنيف:تصوير ثقافي عن كارل غوستاف إميل مانرهايم",
    "Category:Cultural depictions of Carl Jung": "تصنيف:تصوير ثقافي عن كارل يونغ",
    "Category:Cultural depictions of Carl Linnaeus": "تصنيف:تصوير ثقافي عن كارولوس لينيوس",
    "Category:Cultural depictions of Carl Nielsen": "تصنيف:تصوير ثقافي عن كارل نيلسن",
    "Category:Cultural depictions of cartoonists": "تصنيف:تصوير ثقافي عن رسامو كارتون",
    "Category:Cultural depictions of Casey Jones": "تصنيف:تصوير ثقافي عن كيسي جونز",
    "Category:Cultural depictions of Casimir Pulaski": "تصنيف:تصوير ثقافي عن كازيمير بولاسكي",
    "Category:Cultural depictions of Catherine de' Medici": "تصنيف:تصوير ثقافي عن كاترين دي ميديشي",
    "Category:Cultural depictions of Catherine Howard": "تصنيف:تصوير ثقافي عن كاثرين هوارد",
    "Category:Cultural depictions of Catherine of Aragon": "تصنيف:تصوير ثقافي عن كاثرين أرغون",
    "Category:Cultural depictions of Catherine Parr": "تصنيف:تصوير ثقافي عن كاثرين بار",
    "Category:Cultural depictions of Catherine, Princess of Wales": "تصنيف:تصوير ثقافي عن كاثرين أميرة ويلز",
    "Category:Cultural depictions of Catherine the Great": "تصنيف:تصوير ثقافي عن كاترين الثانية",
    "Category:Cultural depictions of Catiline": "تصنيف:تصوير ثقافي عن كاتيلين",
    "Category:Cultural depictions of Cecil Rhodes": "تصنيف:تصوير ثقافي عن سيسل رودس",
    "Category:Cultural depictions of Cesare Borgia": "تصنيف:تصوير ثقافي عن تشيزري بورجا",
    "Category:Cultural depictions of chancellors of Germany": "تصنيف:تصوير ثقافي عن مستشاري ألمانيا",
    "Category:Cultural depictions of Charlemagne": "تصنيف:تصوير ثقافي عن شارلمان",
    "Category:Cultural depictions of Charles Baudelaire": "تصنيف:تصوير ثقافي عن شارل بودلير",
    "Category:Cultural depictions of Charles Darwin": "تصنيف:تصوير ثقافي عن تشارلز داروين",
    "Category:Cultural depictions of Charles de Gaulle": "تصنيف:تصوير ثقافي عن شارل دو غول",
    "Category:Cultural depictions of Charles Dickens": "تصنيف:تصوير ثقافي عن تشارلز ديكنز",
    "Category:Cultural depictions of Charles III": "تصنيف:تصوير ثقافي عن تشارلز الثالث",
    "Category:Cultural depictions of Charles II of England": "تصنيف:تصوير ثقافي عن تشارلز الثاني ملك إنجلترا",
    "Category:Cultural depictions of Charles I of England": "تصنيف:تصوير ثقافي عن تشارلز الأول ملك إنجلترا",
    "Category:Cultural depictions of Charles IV, Holy Roman Emperor": "تصنيف:تصوير ثقافي عن كارل الرابع",
    "Category:Cultural depictions of Charles IX of France": "تصنيف:تصوير ثقافي عن شارل التاسع ملك فرنسا",
    "Category:Cultural depictions of Charles Lindbergh": "تصنيف:تصوير ثقافي عن تشارلز لندبرغ",
    "Category:Cultural depictions of Charles Manson": "تصنيف:تصوير ثقافي عن تشارلز مانسن",
    "Category:Cultural depictions of Charles V, Holy Roman Emperor": "تصنيف:تصوير ثقافي عن شارلكان",
    "Category:Cultural depictions of Charles XII of Sweden": "تصنيف:تصوير ثقافي عن كارل الثاني عشر",
    "Category:Cultural depictions of Charlie Chaplin": "تصنيف:تصوير ثقافي عن تشارلي تشابلن",
    "Category:Cultural depictions of Che Guevara": "تصنيف:تصوير ثقافي عن تشي جيفارا",
    "Category:Cultural depictions of Cher": "تصنيف:تصوير ثقافي عن شير (مغنية)",
    "Category:Cultural depictions of chess players": "تصنيف:تصوير ثقافي عن لاعبو شطرنج",
    "Category:Cultural depictions of Chester A. Arthur": "تصنيف:تصوير ثقافي عن تشستر آرثر",
    "Category:Cultural depictions of Chet Baker": "تصنيف:تصوير ثقافي عن تشيت بيكر",
    "Category:Cultural depictions of Chiang Kai-shek": "تصنيف:تصوير ثقافي عن شيانج كاي شيك",
    "Category:Cultural depictions of Christina, Queen of Sweden": "تصنيف:تصوير ثقافي عن كرستينا ملكة السويد",
    "Category:Cultural depictions of Christopher Columbus": "تصنيف:تصوير ثقافي عن كريستوفر كولومبوس",
    "Category:Cultural depictions of Christopher Marlowe": "تصنيف:تصوير ثقافي عن كريستوفر مارلو",
    "Category:Cultural depictions of Chuck Norris": "تصنيف:تصوير ثقافي عن تشاك نوريس",
    "Category:Cultural depictions of Cicero": "تصنيف:تصوير ثقافي عن شيشرون",
    "Category:Cultural depictions of classical musicians": "تصنيف:تصوير ثقافي عن موسيقيون كلاسيكيون",
    "Category:Cultural depictions of Claude Monet": "تصنيف:تصوير ثقافي عن كلود مونيه",
    "Category:Cultural depictions of Claudius": "تصنيف:تصوير ثقافي عن كلوديوس",
    "Category:Cultural depictions of Cleopatra": "تصنيف:تصوير ثقافي عن كليوباترا السابعة",
    "Category:Cultural depictions of Clint Eastwood": "تصنيف:تصوير ثقافي عن كلينت إيستوود",
    "Category:Cultural depictions of Cnut": "تصنيف:تصوير ثقافي عن كانوت العظيم",
    "Category:Cultural depictions of Cole Porter": "تصنيف:تصوير ثقافي عن كول بورتر",
    "Category:Cultural depictions of Commodus": "تصنيف:تصوير ثقافي عن كومودوس",
    "Category:Cultural depictions of Confucius": "تصنيف:تصوير ثقافي عن كونفوشيوس",
    "Category:Cultural depictions of Constantine the Great": "تصنيف:تصوير ثقافي عن قسطنطين الأول",
    "Category:Cultural depictions of Corazon Aquino": "تصنيف:تصوير ثقافي عن كورازون أكينو",
    "Category:Cultural depictions of country musicians": "تصنيف:تصوير ثقافي عن موسيقيو كانتري",
    "Category:Cultural depictions of cricketers": "تصنيف:تصوير ثقافي عن لاعبو كريكت",
    "Category:Cultural depictions of Croatian people": "تصنيف:تصوير ثقافي عن كروات",
    "Category:Cultural depictions of C. S. Lewis": "تصنيف:تصوير ثقافي عن سي. إس. لويس",
    "Category:Cultural depictions of cue sports players": "تصنيف:تصوير ثقافي عن لاعبو بلياردو",
    "Category:Cultural depictions of cyclists": "تصنيف:تصوير ثقافي عن دراجون",
    "Category:Cultural depictions of Cyrus the Great": "تصنيف:تصوير ثقافي عن كورش الكبير",
    "Category:Cultural depictions of Dalida": "تصنيف:تصوير ثقافي عن داليدا",
    "Category:Cultural depictions of dance musicians": "تصنيف:تصوير ثقافي عن موسيقيو رقص",
    "Category:Cultural depictions of dancers": "تصنيف:تصوير ثقافي عن راقصون",
    "Category:Cultural depictions of Daniel Boone": "تصنيف:تصوير ثقافي عن دانيال بون",
    "Category:Cultural depictions of Dante Alighieri": "تصنيف:تصوير ثقافي عن دانتي أليغييري",
    "Category:Cultural depictions of Darius the Great": "تصنيف:تصوير ثقافي عن دارا الأول",
    "Category:Cultural depictions of David Beckham": "تصنيف:تصوير ثقافي عن ديفيد بيكهام",
    "Category:Cultural depictions of David Ben-Gurion": "تصنيف:تصوير ثقافي عن دافيد بن غوريون",
    "Category:Cultural depictions of David Berkowitz": "تصنيف:تصوير ثقافي عن ديفيد بيركويتز",
    "Category:Cultural depictions of David Bowie": "تصنيف:تصوير ثقافي عن ديفيد بوي",
    "Category:Cultural depictions of David Cameron": "تصنيف:تصوير ثقافي عن ديفيد كاميرون",
    "Category:Cultural depictions of David Garrick": "تصنيف:تصوير ثقافي عن دايفيد جاريك",
    "Category:Cultural depictions of David Livingstone": "تصنيف:تصوير ثقافي عن ديفيد ليفينغستون",
    "Category:Cultural depictions of David Lloyd George": "تصنيف:تصوير ثقافي عن ديفيد لويد جورج",
    "Category:Cultural depictions of Davy Crockett": "تصنيف:تصوير ثقافي عن ديفي كروكيت",
    "Category:Cultural depictions of Democratic Republic of the Congo people": "تصنيف:تصوير ثقافي عن كونغويون ديمقراطيون",
    "Category:Cultural depictions of Deng Xiaoping": "تصنيف:تصوير ثقافي عن دينج شياو بينج",
    "Category:Cultural depictions of dentists": "تصنيف:تصوير ثقافي عن أطباء أسنان",
    "Category:Cultural depictions of D. H. Lawrence": "تصنيف:تصوير ثقافي عن ديفيد هربرت لورانس",
    "Category:Cultural depictions of Diana, Princess of Wales": "تصنيف:تصوير ثقافي عن ديانا أميرة ويلز",
    "Category:Cultural depictions of Dick Cheney": "تصنيف:تصوير ثقافي عن ديك تشيني",
    "Category:Cultural depictions of Diego Maradona": "تصنيف:تصوير ثقافي عن دييغو مارادونا",
    "Category:Cultural depictions of Diocletian": "تصنيف:تصوير ثقافي عن دقلديانوس",
    "Category:Cultural depictions of Diogenes": "تصنيف:تصوير ثقافي عن ديوجانس الكلبي",
    "Category:Cultural depictions of Dmitry Medvedev": "تصنيف:تصوير ثقافي عن دميتري ميدفيديف",
    "Category:Cultural depictions of Dolly Parton": "تصنيف:تصوير ثقافي عن دوللي بارتون",
    "Category:Cultural depictions of Domitian": "تصنيف:تصوير ثقافي عن دومطيانوس",
    "Category:Cultural depictions of Donald Trump": "تصنيف:تصوير ثقافي عن دونالد ترمب",
    "Category:Cultural depictions of Don Bradman": "تصنيف:تصوير ثقافي عن دونالد برادمان",
    "Category:Cultural depictions of Douglas Haig, 1st Earl Haig": "تصنيف:تصوير ثقافي عن دوغلاس هيج",
    "Category:Cultural depictions of Douglas MacArthur": "تصنيف:تصوير ثقافي عن دوغلاس ماكارثر",
    "Category:Cultural depictions of dramatists and playwrights": "تصنيف:تصوير ثقافي عن كتاب دراما ومسرح",
    "Category:Cultural depictions of Duke Ellington": "تصنيف:تصوير ثقافي عن ديوك إلينغتون",
    "Category:Cultural depictions of dukes": "تصنيف:تصوير ثقافي عن دوقات",
    "Category:Cultural depictions of Dutch monarchs": "تصنيف:تصوير ثقافي عن ملكيون هولنديون",
    "Category:Cultural depictions of Dwight D. Eisenhower": "تصنيف:تصوير ثقافي عن دوايت أيزنهاور",
    "Category:Cultural depictions of Dylan Thomas": "تصنيف:تصوير ثقافي عن ديلان توماس",
    "Category:Cultural depictions of Éamon de Valera": "تصنيف:تصوير ثقافي عن إيمون دي فاليرا",
    "Category:Cultural depictions of Eddy Merckx": "تصنيف:تصوير ثقافي عن إيدي ميركس",
    "Category:Cultural depictions of Edgar Allan Poe": "تصنيف:تصوير ثقافي عن إدغار آلان بو",
    "Category:Cultural depictions of Edgar Degas": "تصنيف:تصوير ثقافي عن إدغار ديغا",
    "Category:Cultural depictions of Edgar Rice Burroughs": "تصنيف:تصوير ثقافي عن إدغار رايس بوروس",
    "Category:Cultural depictions of Édith Piaf": "تصنيف:تصوير ثقافي عن إديث بياف",
    "Category:Cultural depictions of Édouard Manet": "تصنيف:تصوير ثقافي عن إدوارد مانيه",
    "Category:Cultural depictions of educators": "تصنيف:تصوير ثقافي عن معلمون",
    "Category:Cultural depictions of Edvard Munch": "تصنيف:تصوير ثقافي عن إدفارت مونك",
    "Category:Cultural depictions of Edward Heath": "تصنيف:تصوير ثقافي عن إدوارد هيث",
    "Category:Cultural depictions of Edward III of England": "تصنيف:تصوير ثقافي عن إدوارد الثالث ملك إنجلترا",
    "Category:Cultural depictions of Edward II of England": "تصنيف:تصوير ثقافي عن إدوارد الثاني ملك إنجلترا",
    "Category:Cultural depictions of Edward I of England": "تصنيف:تصوير ثقافي عن إدوارد الأول ملك إنجلترا",
    "Category:Cultural depictions of Edward IV": "تصنيف:تصوير ثقافي عن إدوارد الرابع ملك إنجلترا",
    "Category:Cultural depictions of Edward Snowden": "تصنيف:تصوير ثقافي عن إدوارد سنودن",
    "Category:Cultural depictions of Edward V": "تصنيف:تصوير ثقافي عن إدوارد الخامس",
    "Category:Cultural depictions of Edward VI": "تصنيف:تصوير ثقافي عن إدوارد السادس",
    "Category:Cultural depictions of Edward VII": "تصنيف:تصوير ثقافي عن إدوارد السابع ملك المملكة المتحدة",
    "Category:Cultural depictions of Egyptian monarchs": "تصنيف:تصوير ثقافي عن ملكيون مصريون",
    "Category:Cultural depictions of Elagabalus": "تصنيف:تصوير ثقافي عن إيل جبل",
    "Category:Cultural depictions of El Cid": "تصنيف:تصوير ثقافي عن إل سيد",
    "Category:Cultural depictions of Eleanor of Aquitaine": "تصنيف:تصوير ثقافي عن إليانور آكيتيان",
    "Category:Cultural depictions of Eleanor Roosevelt": "تصنيف:تصوير ثقافي عن إليانور روزفلت",
    "Category:Cultural depictions of El Greco": "تصنيف:تصوير ثقافي عن إل غريكو",
    "Category:Cultural depictions of Elizabeth I": "تصنيف:تصوير ثقافي عن إليزابيث الأولى ملكة إنجلترا",
    "Category:Cultural depictions of Elizabeth II": "تصنيف:تصوير ثقافي عن إليزابيث الثانية",
    "Category:Cultural depictions of Elizabeth of Russia": "تصنيف:تصوير ثقافي عن إليزابيث إمبراطورة روسيا",
    "Category:Cultural depictions of Elizabeth Taylor": "تصنيف:تصوير ثقافي عن إليزابيث تايلور",
    "Category:Cultural depictions of Elton John": "تصنيف:تصوير ثقافي عن إلتون جون",
    "Category:Cultural depictions of Elvis Presley": "تصنيف:تصوير ثقافي عن إلفيس بريسلي",
    "Category:Cultural depictions of Émile Zola": "تصنيف:تصوير ثقافي عن إميل زولا",
    "Category:Cultural depictions of Emilio Aguinaldo": "تصنيف:تصوير ثقافي عن إميليو أغينالدو",
    "Category:Cultural depictions of Emily Dickinson": "تصنيف:تصوير ثقافي عن إيميلي ديكنسون",
    "Category:Cultural depictions of Emir Kusturica": "تصنيف:تصوير ثقافي عن أمير كوستوريتسا",
    "Category:Cultural depictions of Emmeline Pankhurst": "تصنيف:تصوير ثقافي عن إميلين بانكيرست",
    "Category:Cultural depictions of Emperor Taizong of Tang": "تصنيف:تصوير ثقافي عن الإمبراطور تايزونج",
    "Category:Cultural depictions of Empress Elisabeth of Austria": "تصنيف:تصوير ثقافي عن إليزابيث إمبراطورة النمسا",
    "Category:Cultural depictions of engineers": "تصنيف:تصوير ثقافي عن مهندسون",
    "Category:Cultural depictions of English monarchs": "تصنيف:تصوير ثقافي عن ملكيون إنجليز",
    "Category:Cultural depictions of English people": "تصنيف:تصوير ثقافي عن إنجليز",
    "Category:Cultural depictions of Enrico Caruso": "تصنيف:تصوير ثقافي عن إنريكو كاروسو",
    "Category:Cultural depictions of Ernest Hemingway": "تصنيف:تصوير ثقافي عن إرنست همينغوي",
    "Category:Cultural depictions of Erwin Rommel": "تصنيف:تصوير ثقافي عن إرفين رومل",
    "Category:Cultural depictions of Estonian people": "تصنيف:تصوير ثقافي عن إستونيون",
    "Category:Cultural depictions of Eva Perón": "تصنيف:تصوير ثقافي عن إيفا بيرون",
    "Category:Cultural depictions of explorers": "تصنيف:تصوير ثقافي عن مستكشفون",
    "Category:Cultural depictions of Ezra Pound": "تصنيف:تصوير ثقافي عن عزرا باوند",
    "Category:Cultural depictions of fashion designers": "تصنيف:تصوير ثقافي عن مصممو أزياء",
    "Category:Cultural depictions of Federico García Lorca": "تصنيف:تصوير ثقافي عن فيديريكو غارثيا لوركا",
    "Category:Cultural depictions of Fela Kuti": "تصنيف:تصوير ثقافي عن فيلا كوتي",
    "Category:Cultural depictions of female monarchs": "تصنيف:تصوير ثقافي عن ملكيات",
    "Category:Cultural depictions of Ferdinand II of Aragon": "تصنيف:تصوير ثقافي عن فرناندو الثاني ملك أرغون",
    "Category:Cultural depictions of Ferdinand Marcos": "تصنيف:تصوير ثقافي عن فرديناند ماركوس",
    "Category:Cultural depictions of Fidel Castro": "تصنيف:تصوير ثقافي عن فيدل كاسترو",
    "Category:Cultural depictions of Fidel V. Ramos": "تصنيف:تصوير ثقافي عن فيديل فالديس راموس",
    "Category:Cultural depictions of figure skaters": "تصنيف:تصوير ثقافي عن متزلجون فنيون",
    "Category:Cultural depictions of film directors": "تصنيف:تصوير ثقافي عن مخرجو أفلام",
    "Category:Cultural depictions of Finnish people": "تصنيف:تصوير ثقافي عن فنلنديون",
    "Category:Cultural depictions of first ladies of the United States": "تصنيف:تصوير ثقافي عن السيدات الأولى في الولايات المتحدة",
    "Category:Cultural depictions of Florence Nightingale": "تصنيف:تصوير ثقافي عن فلورنس نايتينجيل",
    "Category:Cultural depictions of folk musicians": "تصنيف:تصوير ثقافي عن موسيقيو فولك",
    "Category:Cultural depictions of Francisco Franco": "تصنيف:تصوير ثقافي عن فرانثيسكو فرانكو",
    "Category:Cultural depictions of Francisco Goya": "تصنيف:تصوير ثقافي عن فرانثيسكو غويا",
    "Category:Cultural depictions of Francis Drake": "تصنيف:تصوير ثقافي عن فرنسيس دريك",
    "Category:Cultural depictions of Francis I of France": "تصنيف:تصوير ثقافي عن فرانسوا الأول ملك فرنسا",
    "Category:Cultural depictions of Francis of Assisi": "تصنيف:تصوير ثقافي عن فرنسيس الأسيزي",
    "Category:Cultural depictions of François Villon": "تصنيف:تصوير ثقافي عن فرانسوا فيلون",
    "Category:Cultural depictions of Franklin D. Roosevelt": "تصنيف:تصوير ثقافي عن فرانكلين د. روزفلت",
    "Category:Cultural depictions of Frank Lloyd Wright": "تصنيف:تصوير ثقافي عن فرانك لويد رايت",
    "Category:Cultural depictions of Frank Sinatra": "تصنيف:تصوير ثقافي عن فرانك سيناترا",
    "Category:Cultural depictions of Frank Zappa": "تصنيف:تصوير ثقافي عن فرانك زابا",
    "Category:Cultural depictions of Franz Joseph I of Austria": "تصنيف:تصوير ثقافي عن فرانتس يوزف الأول",
    "Category:Cultural depictions of Franz Kafka": "تصنيف:تصوير ثقافي عن فرانس كافكا",
    "Category:Cultural depictions of Franz Liszt": "تصنيف:تصوير ثقافي عن فرانز ليست",
    "Category:Cultural depictions of Franz Schubert": "تصنيف:تصوير ثقافي عن فرانز شوبرت",
    "Category:Cultural depictions of fraudsters": "تصنيف:تصوير ثقافي عن محتالون",
    "Category:Cultural depictions of Fred Astaire": "تصنيف:تصوير ثقافي عن فريد أستير",
    "Category:Cultural depictions of Freddie Mercury": "تصنيف:تصوير ثقافي عن فريدي ميركوري",
    "Category:Cultural depictions of Frédéric Chopin": "تصنيف:تصوير ثقافي عن فريدريك شوبان",
    "Category:Cultural depictions of Frederick Douglass": "تصنيف:تصوير ثقافي عن فريدريك دوغلاس",
    "Category:Cultural depictions of Frederick the Great": "تصنيف:تصوير ثقافي عن فريدرش العظيم",
    "Category:Cultural depictions of French monarchs": "تصنيف:تصوير ثقافي عن ملكيون فرنسيون",
    "Category:Cultural depictions of Frida Kahlo": "تصنيف:تصوير ثقافي عن فريدا كاهلو",
    "Category:Cultural depictions of Friedrich Nietzsche": "تصنيف:تصوير ثقافي عن فريدريك نيتشه",
    "Category:Cultural depictions of Friedrich Schiller": "تصنيف:تصوير ثقافي عن فريدرش شيلر",
    "Category:Cultural depictions of F. Scott Fitzgerald": "تصنيف:تصوير ثقافي عن فرنسيس سكوت فيتزجيرالد",
    "Category:Cultural depictions of Gabriele D'Annunzio": "تصنيف:تصوير ثقافي عن غابرييل دانونزيو",
    "Category:Cultural depictions of Galileo Galilei": "تصنيف:تصوير ثقافي عن غاليليو غاليلي",
    "Category:Cultural depictions of Gamal Abdel Nasser": "تصنيف:تصوير ثقافي عن جمال عبد الناصر",
    "Category:Cultural depictions of Gautama Buddha": "تصنيف:تصوير ثقافي عن غوتاما بودا",
    "Category:Cultural depictions of Genghis Khan": "تصنيف:تصوير ثقافي عن جنكيز خان",
    "Category:Cultural depictions of George Armstrong Custer": "تصنيف:تصوير ثقافي عن جورج أرمسترونغ كاستر",
    "Category:Cultural depictions of George Bernard Shaw": "تصنيف:تصوير ثقافي عن جورج برنارد شو",
    "Category:Cultural depictions of George Frideric Handel": "تصنيف:تصوير ثقافي عن جورج فريدريك هاندل",
    "Category:Cultural depictions of George H. W. Bush": "تصنيف:تصوير ثقافي عن جورج بوش الأب",
    "Category:Cultural depictions of George III": "تصنيف:تصوير ثقافي عن جورج الثالث ملك المملكة المتحدة",
    "Category:Cultural depictions of George II of Great Britain": "تصنيف:تصوير ثقافي عن جورج الثاني ملك بريطانيا العظمى",
    "Category:Cultural depictions of George I of Great Britain": "تصنيف:تصوير ثقافي عن جورج الأول ملك بريطانيا العظمى",
    "Category:Cultural depictions of George IV": "تصنيف:تصوير ثقافي عن جورج الرابع ملك المملكة المتحدة",
    "Category:Cultural depictions of George Lucas": "تصنيف:تصوير ثقافي عن لوكاس جورج",
    "Category:Cultural depictions of George Orwell": "تصنيف:تصوير ثقافي عن جورج أورويل",
    "Category:Cultural depictions of Georges Clemenceau": "تصنيف:تصوير ثقافي عن جورج كليمانصو",
    "Category:Cultural depictions of Georges Danton": "تصنيف:تصوير ثقافي عن جورج دانتون",
    "Category:Cultural depictions of Georges Méliès": "تصنيف:تصوير ثقافي عن جورج ميلييس",
    "Category:Cultural depictions of George S. Patton": "تصنيف:تصوير ثقافي عن جورج باتون",
    "Category:Cultural depictions of George V": "تصنيف:تصوير ثقافي عن جورج الخامس ملك المملكة المتحدة",
    "Category:Cultural depictions of George VI": "تصنيف:تصوير ثقافي عن جورج السادس ملك المملكة المتحدة",
    "Category:Cultural depictions of George Washington": "تصنيف:تصوير ثقافي عن جورج واشنطن",
    "Category:Cultural depictions of George W. Bush": "تصنيف:تصوير ثقافي عن جورج بوش الابن",
    "Category:Cultural depictions of Gerald Ford": "تصنيف:تصوير ثقافي عن جيرالد فورد",
    "Category:Cultural depictions of Germanicus": "تصنيف:تصوير ثقافي عن جرمانيقوس",
    "Category:Cultural depictions of German monarchs": "تصنيف:تصوير ثقافي عن ملكيون ألمان",
    "Category:Cultural depictions of German people": "تصنيف:تصوير ثقافي عن ألمان",
    "Category:Cultural depictions of Geronimo": "تصنيف:تصوير ثقافي عن جيرانيمو",
    "Category:Cultural depictions of Gertrude Stein": "تصنيف:تصوير ثقافي عن جيرترود شتاين",
    "Category:Cultural depictions of Giacomo Casanova": "تصنيف:تصوير ثقافي عن جاكومو كازانوفا",
    "Category:Cultural depictions of Gilbert du Motier, Marquis de Lafayette": "تصنيف:تصوير ثقافي عن ماركيس دي لافاييت",
    "Category:Cultural depictions of Giordano Bruno": "تصنيف:تصوير ثقافي عن جوردانو برونو",
    "Category:Cultural depictions of Girolamo Savonarola": "تصنيف:تصوير ثقافي عن سافونارولا",
    "Category:Cultural depictions of Giuseppe Garibaldi": "تصنيف:تصوير ثقافي عن جوزيبي غاريبالدي",
    "Category:Cultural depictions of Giuseppe Verdi": "تصنيف:تصوير ثقافي عن جيوسيبي فيردي",
    "Category:Cultural depictions of Gloria Macapagal Arroyo": "تصنيف:تصوير ثقافي عن غلوريا ماكاباغال أرويو",
    "Category:Cultural depictions of golfers": "تصنيف:تصوير ثقافي عن لاعبو غولف",
    "Category:Cultural depictions of Gordon Brown": "تصنيف:تصوير ثقافي عن جوردون براون",
    "Category:Cultural depictions of governors-general of the Philippines": "تصنيف:تصوير ثقافي عن حكام عموم الفلبين",
    "Category:Cultural depictions of Grace Kelly": "تصنيف:تصوير ثقافي عن غريس كيلي",
    "Category:Cultural depictions of Grand Duchess Anastasia Nikolaevna of Russia": "تصنيف:تصوير ثقافي عن الدوقة الكبرى أناستاسيا نيكولايفنا من روسيا",
    "Category:Cultural depictions of Grigori Rasputin": "تصنيف:تصوير ثقافي عن غريغوري راسبوتين",
    "Category:Cultural depictions of Grover Cleveland": "تصنيف:تصوير ثقافي عن غروفر كليفلاند",
    "Category:Cultural depictions of Guglielmo Marconi": "تصنيف:تصوير ثقافي عن غولييلمو ماركوني",
    "Category:Cultural depictions of Gustav III": "تصنيف:تصوير ثقافي عن غوستاف الثالث",
    "Category:Cultural depictions of Gustavus Adolphus": "تصنيف:تصوير ثقافي عن غوستاف الثاني أدولف",
    "Category:Cultural depictions of Guy Fawkes": "تصنيف:تصوير ثقافي عن جاي فوكس",
    "Category:Cultural depictions of gymnasts": "تصنيف:تصوير ثقافي عن لاعبو جمباز",
    "Category:Cultural depictions of Hadrian": "تصنيف:تصوير ثقافي عن هادريان",
    "Category:Cultural depictions of Haile Selassie": "تصنيف:تصوير ثقافي عن هيلا سيلاسي",
    "Category:Cultural depictions of Haitian people": "تصنيف:تصوير ثقافي عن هايتيون",
    "Category:Cultural depictions of Hank Williams": "تصنيف:تصوير ثقافي عن هانك ويليامز",
    "Category:Cultural depictions of Hannibal": "تصنيف:تصوير ثقافي عن حنبعل",
    "Category:Cultural depictions of Hans Christian Andersen": "تصنيف:تصوير ثقافي عن هانس كريستيان أندرسن",
    "Category:Cultural depictions of Harold Wilson": "تصنيف:تصوير ثقافي عن هارولد ويلسون",
    "Category:Cultural depictions of Harriet Tubman": "تصنيف:تصوير ثقافي عن هاريت توبمان",
    "Category:Cultural depictions of Harry Houdini": "تصنيف:تصوير ثقافي عن هاري هوديني",
    "Category:Cultural depictions of Harry S. Truman": "تصنيف:تصوير ثقافي عن هاري ترومان",
    "Category:Cultural depictions of Harun al-Rashid": "تصنيف:تصوير ثقافي عن هارون الرشيد",
    "Category:Cultural depictions of Hatshepsut": "تصنيف:تصوير ثقافي عن حتشبسوت",
    "Category:Cultural depictions of Heinrich Himmler": "تصنيف:تصوير ثقافي عن هاينريش هيملر",
    "Category:Cultural depictions of Helen Keller": "تصنيف:تصوير ثقافي عن هيلين كيلر",
    "Category:Cultural depictions of Henri de Toulouse-Lautrec": "تصنيف:تصوير ثقافي عن أنري تولوز لوترك",
    "Category:Cultural depictions of Henrik Ibsen": "تصنيف:تصوير ثقافي عن هنريك إبسن",
    "Category:Cultural depictions of Henri Matisse": "تصنيف:تصوير ثقافي عن هنري ماتيس",
    "Category:Cultural depictions of Henry Ford": "تصنيف:تصوير ثقافي عن هنري فورد",
    "Category:Cultural depictions of Henry III of England": "تصنيف:تصوير ثقافي عن هنري الثالث ملك إنجلترا",
    "Category:Cultural depictions of Henry III of France": "تصنيف:تصوير ثقافي عن هنري الثالث ملك فرنسا",
    "Category:Cultural depictions of Henry II of England": "تصنيف:تصوير ثقافي عن هنري الثاني ملك إنجلترا",
    "Category:Cultural depictions of Henry IV of England": "تصنيف:تصوير ثقافي عن هنري الرابع ملك إنجلترا",
    "Category:Cultural depictions of Henry IV of France": "تصنيف:تصوير ثقافي عن هنري الرابع ملك فرنسا",
    "Category:Cultural depictions of Henry Kissinger": "تصنيف:تصوير ثقافي عن هنري كسنجر",
    "Category:Cultural depictions of Henry Morton Stanley": "تصنيف:تصوير ثقافي عن هنري مورتون ستانلي",
    "Category:Cultural depictions of Henry VIII": "تصنيف:تصوير ثقافي عن هنري الثامن ملك إنجلترا",
    "Category:Cultural depictions of Henry VII of England": "تصنيف:تصوير ثقافي عن هنري السابع ملك إنجلترا",
    "Category:Cultural depictions of Henry VI of England": "تصنيف:تصوير ثقافي عن هنري السادس ملك إنجلترا",
    "Category:Cultural depictions of Henry V of England": "تصنيف:تصوير ثقافي عن هنري الخامس ملك إنجلترا",
    "Category:Cultural depictions of Herbert Hoover": "تصنيف:تصوير ثقافي عن هربرت هوفر",
    "Category:Cultural depictions of Hermann Göring": "تصنيف:تصوير ثقافي عن هيرمان غورينغ",
    "Category:Cultural depictions of Herod the Great": "تصنيف:تصوير ثقافي عن هيرودس الأول",
    "Category:Cultural depictions of H. G. Wells": "تصنيف:تصوير ثقافي عن جورج ويلز",
    "Category:Cultural depictions of Hideki Tojo": "تصنيف:تصوير ثقافي عن هيديكي توجو",
    "Category:Cultural depictions of Hillary Clinton": "تصنيف:تصوير ثقافي عن هيلاري كلينتون",
    "Category:Cultural depictions of hip-hop musicians": "تصنيف:تصوير ثقافي عن موسيقيو هيب هوب",
    "Category:Cultural depictions of Hirohito": "تصنيف:تصوير ثقافي عن هيروهيتو",
    "Category:Cultural depictions of Honoré de Balzac": "تصنيف:تصوير ثقافي عن أونوريه دي بلزاك",
    "Category:Cultural depictions of Horatio Nelson": "تصنيف:تصوير ثقافي عن هوراشيو نيلسون",
    "Category:Cultural depictions of Howard Hughes": "تصنيف:تصوير ثقافي عن هاوارد هيوز",
    "Category:Cultural depictions of Hulk Hogan": "تصنيف:تصوير ثقافي عن هولك هوجان",
    "Category:Cultural depictions of Hungarian monarchs": "تصنيف:تصوير ثقافي عن ملكيون مجريون",
    "Category:Cultural depictions of Husayn ibn Ali": "تصنيف:تصوير ثقافي عن الحسين بن علي",
    "Category:Cultural depictions of Hypatia": "تصنيف:تصوير ثقافي عن هيباتيا",
    "Category:Cultural depictions of ice hockey players": "تصنيف:تصوير ثقافي عن لاعبو هوكي جليد",
    "Category:Cultural depictions of Icelandic people": "تصنيف:تصوير ثقافي عن آيسلنديون",
    "Category:Cultural depictions of Idi Amin": "تصنيف:تصوير ثقافي عن عيدي أمين",
    "Category:Cultural depictions of Igor Stravinsky": "تصنيف:تصوير ثقافي عن إيغور سترافينسكي",
    "Category:Cultural depictions of Imran Khan": "تصنيف:تصوير ثقافي عن عمران خان",
    "Category:Cultural depictions of Indian people": "تصنيف:تصوير ثقافي عن هنود",
    "Category:Cultural depictions of Indira Gandhi": "تصنيف:تصوير ثقافي عن أنديرا غاندي",
    "Category:Cultural depictions of Indonesian people": "تصنيف:تصوير ثقافي عن إندونيسيون",
    "Category:Cultural depictions of inventors": "تصنيف:تصوير ثقافي عن مخترعون",
    "Category:Cultural depictions of Irene of Athens": "تصنيف:تصوير ثقافي عن أيرين أثينا",
    "Category:Cultural depictions of Isaac Newton": "تصنيف:تصوير ثقافي عن إسحاق نيوتن",
    "Category:Cultural depictions of Isabella I of Castile": "تصنيف:تصوير ثقافي عن إيزابيلا الأولى ملكة قشتالة",
    "Category:Cultural depictions of Ivan the Terrible": "تصنيف:تصوير ثقافي عن إيفان الرابع",
    "Category:Cultural depictions of Jack Dempsey": "تصنيف:تصوير ثقافي عن جاك دمبسي",
    "Category:Cultural depictions of Jackie Chan": "تصنيف:تصوير ثقافي عن جاكي شان",
    "Category:Cultural depictions of Jackie Robinson": "تصنيف:تصوير ثقافي عن جاكي روبينسون",
    "Category:Cultural depictions of Jack Nicklaus": "تصنيف:تصوير ثقافي عن جاك نيكولاس",
    "Category:Cultural depictions of Jack the Ripper": "تصنيف:تصوير ثقافي عن جاك السفاح",
    "Category:Cultural depictions of Jacqueline Kennedy Onassis": "تصنيف:تصوير ثقافي عن جاكلين كينيدي",
    "Category:Cultural depictions of Jacques Brel": "تصنيف:تصوير ثقافي عن جاك بريل",
    "Category:Cultural depictions of Jacques Cousteau": "تصنيف:تصوير ثقافي عن جاك إيف كوستو",
    "Category:Cultural depictions of Jamaican people": "تصنيف:تصوير ثقافي عن جامايكيون",
    "Category:Cultural depictions of James A. Garfield": "تصنيف:تصوير ثقافي عن جيمس جارفيلد",
    "Category:Cultural depictions of James Brown": "تصنيف:تصوير ثقافي عن جيمس براون",
    "Category:Cultural depictions of James Buchanan": "تصنيف:تصوير ثقافي عن جيمس بيوكانان",
    "Category:Cultural depictions of James Cook": "تصنيف:تصوير ثقافي عن جيمس كوك",
    "Category:Cultural depictions of James Dean": "تصنيف:تصوير ثقافي عن جيمس دين",
    "Category:Cultural depictions of James Francis Edward Stuart": "تصنيف:تصوير ثقافي عن جيمس فرانسيس إدوارد ستيوارت",
    "Category:Cultural depictions of James II of England": "تصنيف:تصوير ثقافي عن جيمس الثاني ملك إنجلترا",
    "Category:Cultural depictions of James Madison": "تصنيف:تصوير ثقافي عن جيمس ماديسون",
    "Category:Cultural depictions of James Monroe": "تصنيف:تصوير ثقافي عن جيمس مونرو",
    "Category:Cultural depictions of James V": "تصنيف:تصوير ثقافي عن جيمس الخامس ملك إسكتلندا",
    "Category:Cultural depictions of James VI and I": "تصنيف:تصوير ثقافي عن جيمس الأول ملك إنجلترا",
    "Category:Cultural depictions of Jane Austen": "تصنيف:تصوير ثقافي عن جاين أوستن",
    "Category:Cultural depictions of Jane Seymour": "تصنيف:تصوير ثقافي عن جين سيمور",
    "Category:Cultural depictions of Jan Hus": "تصنيف:تصوير ثقافي عن يان هوس",
    "Category:Cultural depictions of Janis Joplin": "تصنيف:تصوير ثقافي عن جانيس جوبلين",
    "Category:Cultural depictions of Jan Žižka": "تصنيف:تصوير ثقافي عن يان جيجكا",
    "Category:Cultural depictions of Jawaharlal Nehru": "تصنيف:تصوير ثقافي عن جواهر لال نهرو",
    "Category:Cultural depictions of jazz musicians": "تصنيف:تصوير ثقافي عن موسيقيو جاز",
    "Category:Cultural depictions of Jean-Paul Sartre": "تصنيف:تصوير ثقافي عن جون بول سارتر",
    "Category:Cultural depictions of Jeffrey Dahmer": "تصنيف:تصوير ثقافي عن جيفري دامر",
    "Category:Cultural depictions of Jenny Lind": "تصنيف:تصوير ثقافي عن جيني ليند",
    "Category:Cultural depictions of Jerome": "تصنيف:تصوير ثقافي عن جيروم",
    "Category:Cultural depictions of Jesse James": "تصنيف:تصوير ثقافي عن جيسي جيمس",
    "Category:Cultural depictions of Jesse Owens": "تصنيف:تصوير ثقافي عن جيسي أوينز",
    "Category:Cultural depictions of Jessica Alba": "تصنيف:تصوير ثقافي عن جيسيكا ألبا",
    "Category:Cultural depictions of Jesus": "تصنيف:تصوير ثقافي عن يسوع",
    "Category:Cultural depictions of Jimi Hendrix": "تصنيف:تصوير ثقافي عن جيمي هندريكس",
    "Category:Cultural depictions of Jimmy Carter": "تصنيف:تصوير ثقافي عن جيمي كارتر",
    "Category:Cultural depictions of J. M. Barrie": "تصنيف:تصوير ثقافي عن جيمس ماثيو باري",
    "Category:Cultural depictions of J. M. W. Turner": "تصنيف:تصوير ثقافي عن تيرنر",
    "Category:Cultural depictions of Joan Crawford": "تصنيف:تصوير ثقافي عن جوان كراوفورد",
    "Category:Cultural depictions of Joanna of Castile": "تصنيف:خوانا الأولى",
    "Category:Cultural depictions of Joan of Arc": "تصنيف:تصوير ثقافي عن جان دارك",
    "Category:Cultural depictions of Joe Biden": "تصنيف:تصوير ثقافي عن جو بايدن",
    "Category:Cultural depictions of Joe Louis": "تصنيف:تصوير ثقافي عن جو لويس",
    "Category:Cultural depictions of Johannes Gutenberg": "تصنيف:تصوير ثقافي عن يوهان غوتنبرغ",
    "Category:Cultural depictions of Johannes Kepler": "تصنيف:تصوير ثقافي عن يوهانس كبلر",
    "Category:Cultural depictions of Johannes Vermeer": "تصنيف:تصوير ثقافي عن يوهانس فيرمير",
    "Category:Cultural depictions of Johann Sebastian Bach": "تصنيف:تصوير ثقافي عن يوهان سباستيان باخ",
    "Category:Cultural depictions of Johann Strauss II": "تصنيف:تصوير ثقافي عن يوهان شتراوس الابن",
    "Category:Cultural depictions of Johann Wolfgang von Goethe": "تصنيف:تصوير ثقافي عن يوهان فولفغانغ فون غوته",
    "Category:Cultural depictions of John Adams": "تصنيف:تصوير ثقافي عن جون آدامز",
    "Category:Cultural depictions of John A. Macdonald": "تصنيف:تصوير ثقافي عن جون ماكدونالد",
    "Category:Cultural depictions of John Brown (abolitionist)": "تصنيف:تصوير ثقافي عن جون براون",
    "Category:Cultural depictions of John Dillinger": "تصنيف:تصوير ثقافي عن جون ديلينجر",
    "Category:Cultural depictions of John F. Kennedy": "تصنيف:تصوير ثقافي عن جون كينيدي",
    "Category:Cultural depictions of John, King of England": "تصنيف:تصوير ثقافي عن جون ملك إنجلترا",
    "Category:Cultural depictions of John Lennon": "تصنيف:تصوير ثقافي عن جون لينون",
    "Category:Cultural depictions of John Major": "تصنيف:تصوير ثقافي عن جون ميجر",
    "Category:Cultural depictions of Johnny Cash": "تصنيف:تصوير ثقافي عن جوني كاش",
    "Category:Cultural depictions of John Quincy Adams": "تصنيف:تصوير ثقافي عن جون كوينسي آدامز",
    "Category:Cultural depictions of John Travolta": "تصنيف:تصوير ثقافي عن جون ترافولتا",
    "Category:Cultural depictions of John Wayne Gacy": "تصنيف:تصوير ثقافي عن جون واين جسي",
    "Category:Cultural depictions of José de San Martín": "تصنيف:تصوير ثقافي عن خوسيه دي سان مارتين",
    "Category:Cultural depictions of Joseph Goebbels": "تصنيف:تصوير ثقافي عن يوزف غوبلز",
    "Category:Cultural depictions of Joseph Smith": "تصنيف:تصوير ثقافي عن جوزيف سميث",
    "Category:Cultural depictions of Joseph Stalin": "تصنيف:تصوير ثقافي عن يوسف ستالين",
    "Category:Cultural depictions of José Rizal": "تصنيف:تصوير ثقافي عن خوسيه ريزال",
    "Category:Cultural depictions of Josip Broz Tito": "تصنيف:تصوير ثقافي عن جوزيف بروز تيتو",
    "Category:Cultural depictions of J. Robert Oppenheimer": "تصنيف:تصوير ثقافي عن روبرت أوبنهايمر",
    "Category:Cultural depictions of J. R. R. Tolkien": "تصنيف:تصوير ثقافي عن جون ر. تولكين",
    "Category:Cultural depictions of Juan Perón": "تصنيف:تصوير ثقافي عن خوان بيرون",
    "Category:Cultural depictions of Judas Iscariot": "تصنيف:تصوير ثقافي عن يهوذا الإسخريوطي",
    "Category:Cultural depictions of judges": "تصنيف:تصوير ثقافي عن قضاة",
    "Category:Cultural depictions of Judy Garland": "تصنيف:تصوير ثقافي عن جودي غارلند",
    "Category:Cultural depictions of Jules Verne": "تصنيف:تصوير ثقافي عن جول فيرن",
    "Category:Cultural depictions of Julian Assange": "تصنيف:تصوير ثقافي عن جوليان أسانج",
    "Category:Cultural depictions of Julian (emperor)": "تصنيف:تصوير ثقافي عن يوليان المرتد",
    "Category:Cultural depictions of Julius Caesar": "تصنيف:تصوير ثقافي عن يوليوس قيصر",
    "Category:Cultural depictions of Justinian I": "تصنيف:تصوير ثقافي عن جستينيان الأول",
    "Category:Cultural depictions of Justin Trudeau": "تصنيف:تصوير ثقافي عن جاستن ترودو",
    "Category:Cultural depictions of Kamala Harris": "تصنيف:تصوير ثقافي عن كامالا هاريس",
    "Category:Cultural depictions of Kanye West": "تصنيف:تصوير ثقافي عن كانييه ويست",
    "Category:Cultural depictions of Karen Blixen": "تصنيف:تصوير ثقافي عن كارين بلكسين",
    "Category:Cultural depictions of Karl Marx": "تصنيف:تصوير ثقافي عن كارل ماركس",
    "Category:Cultural depictions of Katharine Hepburn": "تصنيف:تصوير ثقافي عن كاثرين هيبورن",
    "Category:Cultural depictions of Kazi Nazrul Islam": "تصنيف:تصوير ثقافي عن نذر الإسلام",
    "Category:Cultural depictions of Khufu": "تصنيف:تصوير ثقافي عن خوفو",
    "Category:Cultural depictions of Kim Jong Il": "تصنيف:تصوير ثقافي عن كيم جونغ إل",
    "Category:Cultural depictions of Kim Jong Un": "تصنيف:تصوير ثقافي عن كم جونغ أون",
    "Category:Cultural depictions of kings": "تصنيف:تصوير ثقافي عن ملوك",
    "Category:Cultural depictions of Korean people": "تصنيف:تصوير ثقافي عن كوريون",
    "Category:Cultural depictions of Kublai Khan": "تصنيف:تصوير ثقافي عن قوبلاي خان",
    "Category:Cultural depictions of Kurt Cobain": "تصنيف:تصوير ثقافي عن كيرت كوبين",
    "Category:Cultural depictions of Kylie Minogue": "تصنيف:تصوير ثقافي عن كايلي مينوغ",
    "Category:Cultural depictions of Lady Gaga": "تصنيف:تصوير ثقافي عن ليدي غاغا",
    "Category:Cultural depictions of Lady Godiva": "تصنيف:تصوير ثقافي عن ليدي غوديفا",
    "Category:Cultural depictions of Lady Jane Grey": "تصنيف:تصوير ثقافي عن ليدي جين غراي",
    "Category:Cultural depictions of Laozi": "تصنيف:تصوير ثقافي عن لاوتزه",
    "Category:Cultural depictions of Lavrentiy Beria": "تصنيف:تصوير ثقافي عن لافرينتي بيريا",
    "Category:Cultural depictions of lawyers": "تصنيف:تصوير ثقافي عن محامون",
    "Category:Cultural depictions of Lech Wałęsa": "تصنيف:تصوير ثقافي عن ليخ فاونسا",
    "Category:Cultural depictions of Leif Erikson": "تصنيف:تصوير ثقافي عن ليف إريكسون",
    "Category:Cultural depictions of Leni Riefenstahl": "تصنيف:تصوير ثقافي عن ليني ريفنستال",
    "Category:Cultural depictions of Lenny Bruce": "تصنيف:تصوير ثقافي عن ليني بروس",
    "Category:Cultural depictions of Leonard Nimoy": "تصنيف:تصوير ثقافي عن ليونارد نيموي",
    "Category:Cultural depictions of Leonardo da Vinci": "تصنيف:تصوير ثقافي عن ليوناردو دا فينشي",
    "Category:Cultural depictions of Leonid Brezhnev": "تصنيف:تصوير ثقافي عن ليونيد بريجنيف",
    "Category:Cultural depictions of Leon Trotsky": "تصنيف:تصوير ثقافي عن ليون تروتسكي",
    "Category:Cultural depictions of Leo Tolstoy": "تصنيف:تصوير ثقافي عن ليو تولستوي",
    "Category:Cultural depictions of Lewis Carroll": "تصنيف:تصوير ثقافي عن لويس كارول",
    "Category:Cultural depictions of Lionel Messi": "تصنيف:تصوير ثقافي عن ليونيل ميسي",
    "Category:Cultural depictions of Livia": "تصنيف:تصوير ثقافي عن ليفيا دروسيلا",
    "Category:Cultural depictions of Lizzie Borden": "تصنيف:تصوير ثقافي عن ليزي بوردن",
    "Category:Cultural depictions of Lord Byron": "تصنيف:تصوير ثقافي عن لورد بايرون",
    "Category:Cultural depictions of lords": "تصنيف:تصوير ثقافي عن لوردات",
    "Category:Cultural depictions of Louis Armstrong": "تصنيف:تصوير ثقافي عن لويس أرمسترونغ",
    "Category:Cultural depictions of Louis-Ferdinand Céline": "تصنيف:تصوير ثقافي عن لويس-فرديناند سيلين",
    "Category:Cultural depictions of Louis Pasteur": "تصنيف:تصوير ثقافي عن لويس باستور",
    "Category:Cultural depictions of Louis Riel": "تصنيف:تصوير ثقافي عن لويس رئيل",
    "Category:Cultural depictions of Louis VIII of France": "تصنيف:تصوير ثقافي عن لويس الثامن ملك فرنسا",
    "Category:Cultural depictions of Louis XIII": "تصنيف:تصوير ثقافي عن لويس الثالث عشر ملك فرنسا",
    "Category:Cultural depictions of Louis XIV": "تصنيف:تصوير ثقافي عن لويس الرابع عشر ملك فرنسا",
    "Category:Cultural depictions of Louis XV": "تصنيف:تصوير ثقافي عن لويس الخامس عشر ملك فرنسا",
    "Category:Cultural depictions of Louis XVI": "تصنيف:تصوير ثقافي عن لويس السادس عشر ملك فرنسا في فرنسا",
    "Category:Cultural depictions of Luciano Pavarotti": "تصنيف:تصوير ثقافي عن لوتشانو بافاروتي",
    "Category:Cultural depictions of Lucrezia Borgia": "تصنيف:تصوير ثقافي عن لوكريسيا بورجيا",
    "Category:Cultural depictions of Ludvig Holberg": "تصنيف:تصوير ثقافي عن لودفيغ هولبرغ",
    "Category:Cultural depictions of Ludwig II of Bavaria": "تصنيف:تصوير ثقافي عن لودفيك الثاني",
    "Category:Cultural depictions of Ludwig van Beethoven": "تصنيف:تصوير ثقافي عن لودفيج فان بيتهوفن",
    "Category:Cultural depictions of Luis Buñuel": "تصنيف:تصوير ثقافي عن لويس بونويل",
    "Category:Cultural depictions of Lyndon B. Johnson": "تصنيف:تصوير ثقافي عن ليندون جونسون",
    "Category:Cultural depictions of Madonna": "تصنيف:تصوير ثقافي عن مادونا (مغنية)",
    "Category:Cultural depictions of Mae West": "تصنيف:تصوير ثقافي عن ماي وست",
    "Category:Cultural depictions of Mahatma Gandhi": "تصنيف:تصوير ثقافي عن مهاتما غاندي",
    "Category:Cultural depictions of Malaysian people": "تصنيف:تصوير ثقافي عن ماليزيون",
    "Category:Cultural depictions of Malcolm X": "تصنيف:تصوير ثقافي عن مالكوم إكس",
    "Category:Cultural depictions of Manfred von Richthofen": "تصنيف:تصوير ثقافي عن مانفرد فون ريشتهوفن",
    "Category:Cultural depictions of Manmohan Singh": "تصنيف:تصوير ثقافي عن مانموهان سينغ",
    "Category:Cultural depictions of Mao Zedong": "تصنيف:تصوير ثقافي عن ماو تسي تونغ",
    "Category:Cultural depictions of Marcel Proust": "تصنيف:تصوير ثقافي عن مارسيل بروست",
    "Category:Cultural depictions of Marco Polo": "تصنيف:تصوير ثقافي عن ماركو بولو",
    "Category:Cultural depictions of Marcus Aurelius": "تصنيف:تصوير ثقافي عن ماركوس أوريليوس",
    "Category:Cultural depictions of Marcus Junius Brutus": "تصنيف:تصوير ثقافي عن بروتس",
    "Category:Cultural depictions of Margaret Thatcher": "تصنيف:تصوير ثقافي عن مارغريت ثاتشر",
    "Category:Cultural depictions of Marie Antoinette": "تصنيف:تصوير ثقافي عن ماري أنطوانيت",
    "Category:Cultural depictions of Marie Curie": "تصنيف:تصوير ثقافي عن ماري كوري",
    "Category:Cultural depictions of Marilyn Monroe": "تصنيف:تصوير ثقافي عن مارلين مونرو",
    "Category:Cultural depictions of Mark Antony": "تصنيف:تصوير ثقافي عن مارك أنطوني",
    "Category:Cultural depictions of Mark Twain": "تصنيف:تصوير ثقافي عن مارك توين",
    "Category:Cultural depictions of Mark Wahlberg": "تصنيف:تصوير ثقافي عن مارك والبيرغ",
    "Category:Cultural depictions of Marlon Brando": "تصنيف:تصوير ثقافي عن مارلون براندو",
    "Category:Cultural depictions of martial artists": "تصنيف:تصوير ثقافي عن ممارسو فنون قتالية",
    "Category:Cultural depictions of Martin Luther": "تصنيف:تصوير ثقافي عن مارتن لوثر",
    "Category:Cultural depictions of Martin Luther King Jr.": "تصنيف:تصوير ثقافي عن مارتن لوثر كينغ الابن",
    "Category:Cultural depictions of Martin Van Buren": "تصنيف:تصوير ثقافي عن مارتن فان بيورين",
    "Category:Cultural depictions of Mary Boleyn": "تصنيف:تصوير ثقافي عن ماري بولين",
    "Category:Cultural depictions of Mary II": "تصنيف:تصوير ثقافي عن ماري الثانية ملكة إنجلترا",
    "Category:Cultural depictions of Mary I of England": "تصنيف:تصوير ثقافي عن ماري الأولى ملكة إنجلترا",
    "Category:Cultural depictions of Mary-Kate and Ashley Olsen": "تصنيف:تصوير ثقافي عن التوأم أولسين",
    "Category:Cultural depictions of Mary Magdalene": "تصنيف:تصوير ثقافي عن مريم المجدلية",
    "Category:Cultural depictions of Mary of Teck": "تصنيف:تصوير ثقافي عن ماري تك",
    "Category:Cultural depictions of Mary, Queen of Scots": "تصنيف:تصوير ثقافي عن ماري ملكة إسكتلندا",
    "Category:Cultural depictions of Mary Shelley": "تصنيف:تصوير ثقافي عن ماري شيلي",
    "Category:Cultural depictions of Maurice Chevalier": "تصنيف:تصوير ثقافي عن موريس شيفالييه",
    "Category:Cultural depictions of Maximilian I of Mexico": "تصنيف:تصوير ثقافي عن ماكسيميليان إمبراطور المكسيك",
    "Category:Cultural depictions of Maximilien Robespierre": "تصنيف:تصوير ثقافي عن ماكسميليان روبسبيار",
    "Category:Cultural depictions of Meher Baba": "تصنيف:تصوير ثقافي عن مهير بابا",
    "Category:Cultural depictions of Mehmed II": "تصنيف:تصوير ثقافي عن محمد الفاتح",
    "Category:Cultural depictions of Mel Gibson": "تصنيف:تصوير ثقافي عن ميل غيبسون",
    "Category:Cultural depictions of Menachem Begin": "تصنيف:تصوير ثقافي عن مناحم بيجن",
    "Category:Cultural depictions of Michael Collins (astronaut)": "تصنيف:تصوير ثقافي عن مايكل كولينز (رائد فضاء)",
    "Category:Cultural depictions of Michael Jackson": "تصنيف:تصوير ثقافي عن مايكل جاكسون",
    "Category:Cultural depictions of Michael Jordan": "تصنيف:تصوير ثقافي عن مايكل جوردن",
    "Category:Cultural depictions of Michael Moore": "تصنيف:تصوير ثقافي عن مايكل مور",
    "Category:Cultural depictions of Michelangelo": "تصنيف:تصوير ثقافي عن مايكل أنجلو",
    "Category:Cultural depictions of Miguel de Cervantes": "تصنيف:تصوير ثقافي عن ميغيل دي ثيربانتس",
    "Category:Cultural depictions of Mike Tyson": "تصنيف:تصوير ثقافي عن مايك تايسون",
    "Category:Cultural depictions of Mikhail Gorbachev": "تصنيف:تصوير ثقافي عن ميخائيل غورباتشوف",
    "Category:Cultural depictions of Miley Cyrus": "تصنيف:تصوير ثقافي عن مايلي سايرس",
    "Category:Cultural depictions of mistresses": "تصنيف:تصوير ثقافي عن عشيقات",
    "Category:Cultural depictions of Miyamoto Musashi": "تصنيف:تصوير ثقافي عن مياموتو موساشي",
    "Category:Cultural depictions of models": "تصنيف:تصوير ثقافي عن عارضو أزياء",
    "Category:Cultural depictions of Molière": "تصنيف:تصوير ثقافي عن موليير",
    "Category:Cultural depictions of Mother Teresa": "تصنيف:تصوير ثقافي عن الأم تريزا",
    "Category:Cultural depictions of motorcycle racers": "تصنيف:تصوير ثقافي عن متسابقو دراجات نارية",
    "Category:Cultural depictions of Mr. T": "تصنيف:تصوير ثقافي عن مستر تي",
    "Category:Cultural depictions of Muammar Gaddafi": "تصنيف:تصوير ثقافي عن معمر القذافي",
    "Category:Cultural depictions of Muhammad": "تصنيف:تصوير ثقافي عن محمد",
    "Category:Cultural depictions of Muhammad Ali": "تصنيف:تصوير ثقافي عن محمد علي",
    "Category:Cultural depictions of Muhammad Ali Jinnah": "تصنيف:تصوير ثقافي عن محمد علي جناح",
    "Category:Cultural depictions of Mustafa Kemal Atatürk": "تصنيف:تصوير ثقافي عن مصطفى كمال أتاتورك",
    "Category:Cultural depictions of Napoleon": "تصنيف:تصوير ثقافي عن نابليون",
    "Category:Cultural depictions of Napoleon II": "تصنيف:تصوير ثقافي عن نابليون الثاني",
    "Category:Cultural depictions of Napoleon III": "تصنيف:تصوير ثقافي عن نابليون الثالث",
    "Category:Cultural depictions of Narendra Modi": "تصنيف:تصوير ثقافي عن ناريندرا مودي",
    "Category:Cultural depictions of Nat Turner": "تصنيف:تصوير ثقافي عن نات ترنر",
    "Category:Cultural depictions of Nebuchadnezzar II": "تصنيف:تصوير ثقافي عن نبوخذ نصر الثاني",
    "Category:Cultural depictions of Nefertari": "تصنيف:تصوير ثقافي عن نفرتاري",
    "Category:Cultural depictions of Nefertiti": "تصنيف:تصوير ثقافي عن نفرتيتي",
    "Category:Cultural depictions of Neil Armstrong": "تصنيف:تصوير ثقافي عن نيل آرمسترونغ",
    "Category:Cultural depictions of Nelson Mandela": "تصنيف:تصوير ثقافي عن نيلسون مانديلا",
    "Category:Cultural depictions of Nepalese people": "تصنيف:تصوير ثقافي عن نيباليون",
    "Category:Cultural depictions of Nero": "تصنيف:تصوير ثقافي عن نيرون",
    "Category:Cultural depictions of Neville Chamberlain": "تصنيف:تصوير ثقافي عن نيفيل تشامبرلين",
    "Category:Cultural depictions of Niccolò Machiavelli": "تصنيف:تصوير ثقافي عن نيكولو مكيافيلي",
    "Category:Cultural depictions of Nicholas II of Russia": "تصنيف:تصوير ثقافي عن نيقولا الثاني",
    "Category:Cultural depictions of Nicolae Ceaușescu": "تصنيف:تصوير ثقافي عن نيكولاي تشاوتشيسكو",
    "Category:Cultural depictions of Nicolaus Copernicus": "تصنيف:تصوير ثقافي عن نيكولاس كوبرنيكوس",
    "Category:Cultural depictions of Nigel Farage": "تصنيف:تصوير ثقافي عن نايغل فاريج",
    "Category:Cultural depictions of Nigerian people": "تصنيف:تصوير ثقافي عن نيجيريون",
    "Category:Cultural depictions of Nikita Khrushchev": "تصنيف:تصوير ثقافي عن نيكيتا خروتشوف",
    "Category:Cultural depictions of Nikola Tesla": "تصنيف:تصوير ثقافي عن نيكولا تسلا",
    "Category:Cultural depictions of nobility": "تصنيف:تصوير ثقافي عن نبلاء",
    "Category:Cultural depictions of Nostradamus": "تصنيف:تصوير ثقافي عن نوستراداموس",
    "Category:Cultural depictions of nurses": "تصنيف:تصوير ثقافي عن ممرضون",
    "Category:Cultural depictions of O. J. Simpson": "تصنيف:تصوير ثقافي عن أو جاي سيمبسون",
    "Category:Cultural depictions of Oliver Cromwell": "تصنيف:تصوير ثقافي عن أوليفر كرومويل",
    "Category:Cultural depictions of Omar Khayyam": "تصنيف:تصوير ثقافي عن عمر الخيام",
    "Category:Cultural depictions of Orson Welles": "تصنيف:تصوير ثقافي عن أورسن ويلز",
    "Category:Cultural depictions of Osama bin Laden": "تصنيف:تصوير ثقافي عن أسامة بن لادن",
    "Category:Cultural depictions of Oscar Wilde": "تصنيف:تصوير ثقافي عن أوسكار وايلد",
    "Category:Cultural depictions of Oswald Mosley": "تصنيف:تصوير ثقافي عن أوزوالد موزلي",
    "Category:Cultural depictions of Otto von Bismarck": "تصنيف:تصوير ثقافي عن أوتو فون بسمارك",
    "Category:Cultural depictions of Ovid": "تصنيف:تصوير ثقافي عن أوفيد",
    "Category:Cultural depictions of Ozzy Osbourne": "تصنيف:تصوير ثقافي عن أوزي أوزبورن",
    "Category:Cultural depictions of Pablo Escobar": "تصنيف:تصوير ثقافي عن بابلو إسكوبار",
    "Category:Cultural depictions of Pablo Neruda": "تصنيف:تصوير ثقافي عن بابلو نيرودا",
    "Category:Cultural depictions of Pablo Picasso": "تصنيف:تصوير ثقافي عن بابلو بيكاسو",
    "Category:Cultural depictions of painters": "تصنيف:تصوير ثقافي عن رسامون",
    "Category:Cultural depictions of Panamanian people": "تصنيف:تصوير ثقافي عن بنميون",
    "Category:Cultural depictions of Pancho Villa": "تصنيف:تصوير ثقافي عن بانشو فيا",
    "Category:Cultural depictions of Paris Hilton": "تصنيف:تصوير ثقافي عن باريس هيلتون",
    "Category:Cultural depictions of Patrick Henry": "تصنيف:تصوير ثقافي عن باتريك هنري",
    "Category:Cultural depictions of Paul Gauguin": "تصنيف:تصوير ثقافي عن بول غوغان",
    "Category:Cultural depictions of Paul Kruger": "تصنيف:تصوير ثقافي عن بول كروغر",
    "Category:Cultural depictions of Paul Revere": "تصنيف:تصوير ثقافي عن بول ريفير",
    "Category:Cultural depictions of Paul the Apostle": "تصنيف:تصوير ثقافي عن بولس",
    "Category:Cultural depictions of Paul von Hindenburg": "تصنيف:تصوير ثقافي عن باول فون هيندنبورغ",
    "Category:Cultural depictions of Pelé": "تصنيف:تصوير ثقافي عن بيليه",
    "Category:Cultural depictions of people by ethnicity": "تصنيف:تصوير ثقافي عن أشخاص حسب المجموعة العرقية",
    "Category:Cultural depictions of people by nationality": "تصنيف:تصوير ثقافي عن أشخاص حسب الجنسية",
    "Category:Cultural depictions of people by occupation": "تصنيف:تصوير ثقافي عن أشخاص حسب المهنة",
    "Category:Cultural depictions of people from Georgia (country)": "تصنيف:تصوير ثقافي عن أشخاص من جورجيا",
    "Category:Cultural depictions of Percy Bysshe Shelley": "تصنيف:تصوير ثقافي عن بيرسي بيش شيلي",
    "Category:Cultural depictions of Peter the Great": "تصنيف:تصوير ثقافي عن بطرس الأكبر",
    "Category:Cultural depictions of Philip II of Spain": "تصنيف:تصوير ثقافي عن فيليب الثاني ملك إسبانيا",
    "Category:Cultural depictions of Philip IV of Spain": "تصنيف:تصوير ثقافي عن فيليب الرابع ملك إسبانيا",
    "Category:Cultural depictions of Philippe Pétain": "تصنيف:تصوير ثقافي عن فيليب بيتان",
    "Category:Cultural depictions of philosophers": "تصنيف:تصوير ثقافي عن فلاسفة",
    "Category:Cultural depictions of photographers": "تصنيف:تصوير ثقافي عن مصورون",
    "Category:Cultural depictions of physicians": "تصنيف:تصوير ثقافي عن أطباء",
    "Category:Cultural depictions of Pierre-Auguste Renoir": "تصنيف:تصوير ثقافي عن أوغوست رينوار",
    "Category:Cultural depictions of Pierre Trudeau": "تصنيف:تصوير ثقافي عن بيير ترودو",
    "Category:Cultural depictions of pirates": "تصنيف:تصوير ثقافي عن قراصنة",
    "Category:Cultural depictions of Plato": "تصنيف:تصوير ثقافي عن أفلاطون",
    "Category:Cultural depictions of players of American football": "تصنيف:تصوير ثقافي عن لاعبو كرة قدم أمريكية",
    "Category:Cultural depictions of Pocahontas": "تصنيف:تصوير ثقافي عن بوكاهونتس",
    "Category:Cultural depictions of poets": "تصنيف:تصوير ثقافي عن شعراء",
    "Category:Cultural depictions of police officers": "تصنيف:تصوير ثقافي عن ضباط شرطة",
    "Category:Cultural depictions of police officers by nationality": "تصنيف:تصوير ثقافي عن ضباط شرطة حسب الجنسية",
    "Category:Cultural depictions of Pompeia (wife of Caesar)": "تصنيف:تصوير ثقافي عن بومبيه",
    "Category:Cultural depictions of Pompey": "تصنيف:تصوير ثقافي عن بومبيوس الكبير",
    "Category:Cultural depictions of Pontius Pilate": "تصنيف:تصوير ثقافي عن بيلاطس البنطي",
    "Category:Cultural depictions of Pope Alexander VI": "تصنيف:تصوير ثقافي عن إسكندر السادس",
    "Category:Cultural depictions of Pope Benedict XVI": "تصنيف:تصوير ثقافي عن بندكت السادس عشر",
    "Category:Cultural depictions of Pope Innocent X": "تصنيف:تصوير ثقافي عن إينوسنت العاشر",
    "Category:Cultural depictions of Pope John Paul I": "تصنيف:تصوير ثقافي عن يوحنا بولس الأول",
    "Category:Cultural depictions of Pope John Paul II": "تصنيف:تصوير ثقافي عن البابا يوحنا بولص الثاني",
    "Category:Cultural depictions of Pope John XXIII": "تصنيف:تصوير ثقافي عن يوحنا الثالث والعشرون",
    "Category:Cultural depictions of Pope Julius II": "تصنيف:تصوير ثقافي عن يوليوس الثاني",
    "Category:Cultural depictions of Pope Pius VII": "تصنيف:تصوير ثقافي عن بيوس السابع",
    "Category:Cultural depictions of Pope Pius XII": "تصنيف:تصوير ثقافي عن بيوس الثاني عشر",
    "Category:Cultural depictions of popes": "تصنيف:تصوير ثقافي عن بابوات",
    "Category:Cultural depictions of Pope Urban VIII": "تصنيف:تصوير ثقافي عن أربانوس الثامن",
    "Category:Cultural depictions of pop musicians": "تصنيف:تصوير ثقافي عن موسيقيو بوب",
    "Category:Cultural depictions of Poppaea Sabina": "تصنيف:تصوير ثقافي عن بوبايا سابينا",
    "Category:Cultural depictions of pornographic film actors": "تصنيف:تصوير ثقافي عن ممثلو أفلام إباحية",
    "Category:Cultural depictions of presidents": "تصنيف:تصوير ثقافي عن رؤساء",
    "Category:Cultural depictions of presidents of Chile": "تصنيف:تصوير ثقافي عن رؤساء تشيلي",
    "Category:Cultural depictions of presidents of China": "تصنيف:تصوير ثقافي عن رؤساء الصين",
    "Category:Cultural depictions of presidents of Cuba": "تصنيف:تصوير ثقافي عن رؤساء كوبا",
    "Category:Cultural depictions of presidents of Egypt": "تصنيف:تصوير ثقافي عن رؤساء مصر",
    "Category:Cultural depictions of presidents of France": "تصنيف:تصوير ثقافي عن رؤساء فرنسا",
    "Category:Cultural depictions of presidents of Mexico": "تصنيف:تصوير ثقافي عن رؤساء المكسيك",
    "Category:Cultural depictions of presidents of North Korea": "تصنيف:تصوير ثقافي عن رؤساء كوريا الشمالية",
    "Category:Cultural depictions of presidents of Russia": "تصنيف:تصوير ثقافي عن رؤساء روسيا",
    "Category:Cultural depictions of presidents of South Africa": "تصنيف:تصوير ثقافي عن رؤساء جنوب إفريقيا",
    "Category:Cultural depictions of presidents of the Philippines": "تصنيف:تصوير ثقافي عن رؤساء الفلبين",
    "Category:Cultural depictions of presidents of the United States": "تصنيف:تصوير ثقافي عن رؤساء الولايات المتحدة",
    "Category:Cultural depictions of prime ministers of Australia": "تصنيف:تصوير ثقافي عن رؤساء وزراء أستراليا",
    "Category:Cultural depictions of prime ministers of Canada": "تصنيف:تصوير ثقافي عن رؤساء وزراء كندا",
    "Category:Cultural depictions of prime ministers of France": "تصنيف:تصوير ثقافي عن رؤساء وزراء فرنسا",
    "Category:Cultural depictions of prime ministers of India": "تصنيف:تصوير ثقافي عن رؤساء وزراء الهند",
    "Category:Cultural depictions of prime ministers of Israel": "تصنيف:تصوير ثقافي عن رؤساء وزراء إسرائيل",
    "Category:Cultural depictions of prime ministers of Italy": "تصنيف:تصوير ثقافي عن رؤساء وزراء إيطاليا",
    "Category:Cultural depictions of prime ministers of Sri Lanka": "تصنيف:تصوير ثقافي عن رؤساء وزراء سريلانكا",
    "Category:Cultural depictions of prime ministers of the United Kingdom": "تصنيف:تصوير ثقافي عن رؤساء وزراء المملكة المتحدة",
    "Category:Cultural depictions of Prince Albert of Saxe-Coburg and Gotha": "تصنيف:تصوير ثقافي عن ألبرت (الأمير الزوج)",
    "Category:Cultural depictions of Prince Harry, Duke of Sussex": "تصنيف:تصوير ثقافي عن هاري دوق ساسكس",
    "Category:Cultural depictions of Prince Philip, Duke of Edinburgh": "تصنيف:تصوير ثقافي عن فيليب دوق إدنبرة",
    "Category:Cultural depictions of princes": "تصنيف:تصوير ثقافي عن أمراء",
    "Category:Cultural depictions of princesses": "تصنيف:تصوير ثقافي عن أميرات",
    "Category:Cultural depictions of Princess Margaret, Countess of Snowdon": "تصنيف:تصوير ثقافي عن مارجريت كونتيسة سنودون",
    "Category:Cultural depictions of professional wrestlers": "تصنيف:تصوير ثقافي عن مصارعون محترفون",
    "Category:Cultural depictions of prostitutes": "تصنيف:تصوير ثقافي عن داعرات",
    "Category:Cultural depictions of publishers": "تصنيف:تصوير ثقافي عن ناشرون",
    "Category:Cultural depictions of Puerto Rican people": "تصنيف:تصوير ثقافي عن بورتوريكيون",
    "Category:Cultural depictions of Puyi": "تصنيف:تصوير ثقافي عن بوئي",
    "Category:Cultural depictions of Pyotr Ilyich Tchaikovsky": "تصنيف:تصوير ثقافي عن بيتر إليتش تشايكوفسكي",
    "Category:Cultural depictions of Pythagoras": "تصنيف:تصوير ثقافي عن فيثاغورس",
    "Category:Cultural depictions of Qin Shi Huang": "تصنيف:تصوير ثقافي عن تشين شي هوانج",
    "Category:Cultural depictions of Queen Camilla": "تصنيف:تصوير ثقافي عن كاميلا الملكة القرينة",
    "Category:Cultural depictions of Queen Elizabeth the Queen Mother": "تصنيف:تصوير ثقافي عن إليزابيث باوز ليون",
    "Category:Cultural depictions of Queen Victoria": "تصنيف:تصوير ثقافي عن الملكة فيكتوريا",
    "Category:Cultural depictions of Quentin Tarantino": "تصنيف:تصوير ثقافي عن كوينتن تارانتينو",
    "Category:Cultural depictions of Rabindranath Tagore": "تصنيف:تصوير ثقافي عن روبندرونات طاغور",
    "Category:Cultural depictions of racing drivers": "تصنيف:تصوير ثقافي عن سائقو سيارات سباق",
    "Category:Cultural depictions of Radovan Karadžić": "تصنيف:تصوير ثقافي عن رادوفان كاراديتش",
    "Category:Cultural depictions of Ragnar Lodbrok": "تصنيف:تصوير ثقافي عن راغنار لوثبروك",
    "Category:Cultural depictions of Rajesh Khanna": "تصنيف:تصوير ثقافي عن راجيش خانا",
    "Category:Cultural depictions of Ramesses II": "تصنيف:تصوير ثقافي عن رمسيس الثاني",
    "Category:Cultural depictions of Raoul Wallenberg": "تصنيف:تصوير ثقافي عن راؤول ولنبرغ",
    "Category:Cultural depictions of Raphael": "تصنيف:تصوير ثقافي عن رافاييل",
    "Category:Cultural depictions of reggae musicians": "تصنيف:تصوير ثقافي عن موسيقيو ريغيه",
    "Category:Cultural depictions of Rembrandt": "تصنيف:تصوير ثقافي عن رامبرانت",
    "Category:Cultural depictions of René Descartes": "تصنيف:تصوير ثقافي عن رينيه ديكارت",
    "Category:Cultural depictions of rhythm and blues musicians": "تصنيف:تصوير ثقافي عن موسيقيو ريذم أند بلوز",
    "Category:Cultural depictions of Richard Burton": "تصنيف:تصوير ثقافي عن ريتشارد برتون",
    "Category:Cultural depictions of Richard III of England": "تصنيف:تصوير ثقافي عن ريتشارد الثالث ملك إنجلترا",
    "Category:Cultural depictions of Richard II of England": "تصنيف:تصوير ثقافي عن ريتشارد الثاني ملك إنجلترا",
    "Category:Cultural depictions of Richard I of England": "تصنيف:تصوير ثقافي عن ريتشارد الأول ملك إنجلترا",
    "Category:Cultural depictions of Richard Nixon": "تصنيف:تصوير ثقافي عن ريتشارد نيكسون",
    "Category:Cultural depictions of Richard Ramirez": "تصنيف:تصوير ثقافي عن ريتشارد راميرز",
    "Category:Cultural depictions of Richard Wagner": "تصنيف:تصوير ثقافي عن ريتشارد فاغنر",
    "Category:Cultural depictions of Roald Dahl": "تصنيف:تصوير ثقافي عن روالد دال",
    "Category:Cultural depictions of robbers": "تصنيف:تصوير ثقافي عن لصوص",
    "Category:Cultural depictions of Robert Burns": "تصنيف:تصوير ثقافي عن روبرت برنز",
    "Category:Cultural depictions of Robert E. Lee": "تصنيف:تصوير ثقافي عن روبرت إدوارد لي",
    "Category:Cultural depictions of Robert Falcon Scott": "تصنيف:تصوير ثقافي عن روبرت فالكون سكوت",
    "Category:Cultural depictions of Robert F. Kennedy": "تصنيف:تصوير ثقافي عن روبرت كينيدي",
    "Category:Cultural depictions of Robert Johnson": "تصنيف:تصوير ثقافي عن روبرت جونسون",
    "Category:Cultural depictions of Robert Peel": "تصنيف:تصوير ثقافي عن روبرت بيل",
    "Category:Cultural depictions of Robin Williams": "تصنيف:تصوير ثقافي عن روبن ويليامز",
    "Category:Cultural depictions of rock musicians": "تصنيف:تصوير ثقافي عن موسيقيو روك",
    "Category:Cultural depictions of Rodrigo Duterte": "تصنيف:تصوير ثقافي عن رودريغو دوتيرتي",
    "Category:Cultural depictions of Roman emperors": "تصنيف:تصوير ثقافي عن أباطرة رومان",
    "Category:Cultural depictions of Roman princesses": "تصنيف:تصوير ثقافي عن أميرات رومانيات",
    "Category:Cultural depictions of Ronald Reagan": "تصنيف:تصوير ثقافي عن رونالد ريغان",
    "Category:Cultural depictions of Rosa Luxemburg": "تصنيف:تصوير ثقافي عن روزا لوكسمبورغ",
    "Category:Cultural depictions of Rosa Parks": "تصنيف:تصوير ثقافي عن روزا باركس",
    "Category:Cultural depictions of Rudolf II, Holy Roman Emperor": "تصنيف:تصوير ثقافي عن رودولف الثاني",
    "Category:Cultural depictions of Rudolph Valentino": "تصنيف:تصوير ثقافي عن رودلف فالنتينو",
    "Category:Cultural depictions of rugby footballers": "تصنيف:تصوير ثقافي عن لاعبو رجبي",
    "Category:Cultural depictions of Ruhollah Khomeini": "تصنيف:تصوير ثقافي عن روح الله الخميني",
    "Category:Cultural depictions of Russian monarchs": "تصنيف:تصوير ثقافي عن ملكيون روس",
    "Category:Cultural depictions of Russian people": "تصنيف:تصوير ثقافي عن روس",
    "Category:Cultural depictions of Ruth Bader Ginsburg": "تصنيف:تصوير ثقافي عن روث بادر غينسبورغ",
    "Category:Cultural depictions of Rutherford B. Hayes": "تصنيف:تصوير ثقافي عن رذرفورد هايز",
    "Category:Cultural depictions of Sacagawea": "تصنيف:تصوير ثقافي عن ساكاجاويا",
    "Category:Cultural depictions of Sachin Tendulkar": "تصنيف:تصوير ثقافي عن ساشين تندولكار",
    "Category:Cultural depictions of Saddam Hussein": "تصنيف:تصوير ثقافي عن صدام حسين",
    "Category:Cultural depictions of Saint Patrick": "تصنيف:تصوير ثقافي عن القديس باتريك",
    "Category:Cultural depictions of Saint Peter": "تصنيف:تصوير ثقافي عن بطرس الرسول",
    "Category:Cultural depictions of Saint Sava": "تصنيف:تصوير ثقافي عن القديس سابا",
    "Category:Cultural depictions of Saladin": "تصنيف:تصوير ثقافي عن صلاح الدين الأيوبي",
    "Category:Cultural depictions of Salman Khan": "تصنيف:تصوير ثقافي عن سلمان خان",
    "Category:Cultural depictions of Salman Rushdie": "تصنيف:تصوير ثقافي عن سلمان رشدي",
    "Category:Cultural depictions of Salvador Allende": "تصنيف:تصوير ثقافي عن سلفادور أليندي",
    "Category:Cultural depictions of Salvadoran people": "تصنيف:تصوير ثقافي عن سلفادوريون",
    "Category:Cultural depictions of Salvador Dalí": "تصنيف:تصوير ثقافي عن سلفادور دالي",
    "Category:Cultural depictions of Sammy Davis Jr.": "تصنيف:تصوير ثقافي عن سامي ديفيس جونيور",
    "Category:Cultural depictions of samurai": "تصنيف:تصوير ثقافي عن سامورايون",
    "Category:Cultural depictions of Sappho": "تصنيف:تصوير ثقافي عن صافو",
    "Category:Cultural depictions of Sarah Palin": "تصنيف:تصوير ثقافي عن سارة بالين",
    "Category:Cultural depictions of Satyajit Ray": "تصنيف:تصوير ثقافي عن ساتياجيت راي",
    "Category:Cultural depictions of scientists": "تصنيف:تصوير ثقافي عن علماء",
    "Category:Cultural depictions of Scottish monarchs": "تصنيف:تصوير ثقافي عن ملكيون إسكتلنديون",
    "Category:Cultural depictions of screenwriters": "تصنيف:تصوير ثقافي عن كتاب سيناريو",
    "Category:Cultural depictions of sculptors": "تصنيف:تصوير ثقافي عن نحاتون",
    "Category:Cultural depictions of Sejong the Great": "تصنيف:تصوير ثقافي عن سيجونغ العظيم ملك جوسون",
    "Category:Cultural depictions of Selena": "تصنيف:تصوير ثقافي عن سيلينا",
    "Category:Cultural depictions of Serbian people": "تصنيف:تصوير ثقافي عن صرب",
    "Category:Cultural depictions of serial killers": "تصنيف:تصوير ثقافي عن قتلة متسلسلون",
    "Category:Cultural depictions of Servius Tullius": "تصنيف:تصوير ثقافي عن سيرفيوس توليوس",
    "Category:Cultural depictions of Seti I": "تصنيف:تصوير ثقافي عن سيتي الأول",
    "Category:Cultural depictions of Shah Rukh Khan": "تصنيف:تصوير ثقافي عن شاه رخ خان",
    "Category:Cultural depictions of Sheikh Mujibur Rahman": "تصنيف:تصوير ثقافي عن مجيب الرحمن",
    "Category:Cultural depictions of Shirley Temple": "تصنيف:تصوير ثقافي عن شيرلي تيمبل",
    "Category:Cultural depictions of Shivaji": "تصنيف:تصوير ثقافي عن شيفاجي",
    "Category:Cultural depictions of sideshow performers": "تصنيف:تصوير ثقافي عن مؤدو عروض",
    "Category:Cultural depictions of Sigmund Freud": "تصنيف:تصوير ثقافي عن سيغموند فرويد",
    "Category:Cultural depictions of Silvio Berlusconi": "تصنيف:تصوير ثقافي عن سيلفيو برلسكوني",
    "Category:Cultural depictions of Simón Bolívar": "تصنيف:تصوير ثقافي عن سيمون بوليفار",
    "Category:Cultural depictions of Simone de Beauvoir": "تصنيف:تصوير ثقافي عن سيمون دو بوفوار",
    "Category:Cultural depictions of Siti Nurhaliza": "تصنيف:تصوير ثقافي عن سيتي نورهاليزا",
    "Category:Cultural depictions of Sitting Bull": "تصنيف:تصوير ثقافي عن الثور الجالس",
    "Category:Cultural depictions of Skanderbeg": "تصنيف:تصوير ثقافي عن إسكندر بك",
    "Category:Cultural depictions of skateboarders": "تصنيف:تصوير ثقافي عن متزلجو ألواح",
    "Category:Cultural depictions of skiers": "تصنيف:تصوير ثقافي عن متزحلقون",
    "Category:Cultural depictions of slaves": "تصنيف:تصوير ثقافي عن عبيد",
    "Category:Cultural depictions of Slobodan Milošević": "تصنيف:تصوير ثقافي عن سلوبودان ميلوشيفيتش",
    "Category:Cultural depictions of socialites": "تصنيف:تصوير ثقافي عن اجتماعيون",
    "Category:Cultural depictions of Socrates": "تصنيف:تصوير ثقافي عن سقراط",
    "Category:Cultural depictions of soldiers": "تصنيف:تصوير ثقافي عن مجندون",
    "Category:Cultural depictions of soul musicians": "تصنيف:تصوير ثقافي عن موسيقيو السول",
    "Category:Cultural depictions of Soviet people": "تصنيف:تصوير ثقافي عن سوفيت",
    "Category:Cultural depictions of Spanish monarchs": "تصنيف:تصوير ثقافي عن ملكيون إسبان",
    "Category:Cultural depictions of Spanish people": "تصنيف:تصوير ثقافي عن إسبان",
    "Category:Cultural depictions of Spartacus": "تصنيف:تصوير ثقافي عن سبارتاكوس",
    "Category:Cultural depictions of spies": "تصنيف:تصوير ثقافي عن جواسيس",
    "Category:Cultural depictions of sportspeople": "تصنيف:تصوير ثقافي عن رياضيون",
    "Category:Cultural depictions of Stan Lee": "تصنيف:تصوير ثقافي عن ستان لي",
    "Category:Cultural depictions of Stanley Baldwin": "تصنيف:تصوير ثقافي عن ستانلي بلدوين",
    "Category:Cultural depictions of Stanley Kubrick": "تصنيف:تصوير ثقافي عن ستانلي كوبريك",
    "Category:Cultural depictions of Stephen Foster": "تصنيف:تصوير ثقافي عن ستيفن فوستر",
    "Category:Cultural depictions of Stephen Hawking": "تصنيف:تصوير ثقافي عن ستيفن هوكينغ",
    "Category:Cultural depictions of Steve Jobs": "تصنيف:تصوير ثقافي عن ستيف جوبز",
    "Category:Cultural depictions of Steven Spielberg": "تصنيف:تصوير ثقافي عن ستيفن سبيلبرغ",
    "Category:Cultural depictions of Stonewall Jackson": "تصنيف:تصوير ثقافي عن ستونوول جاكسون",
    "Category:Cultural depictions of Subhas Chandra Bose": "تصنيف:تصوير ثقافي عن سوبهاش شاندرا بوز",
    "Category:Cultural depictions of Sudanese people": "تصنيف:تصوير ثقافي عن سودانيون",
    "Category:Cultural depictions of Suleiman the Magnificent": "تصنيف:تصوير ثقافي عن سليمان القانوني",
    "Category:Cultural depictions of Sulla": "تصنيف:تصوير ثقافي عن سولا",
    "Category:Cultural depictions of Sun Tzu": "تصنيف:تصوير ثقافي عن سون تزو",
    "Category:Cultural depictions of Sun Yat-sen": "تصنيف:تصوير ثقافي عن سون يات سين",
    "Category:Cultural depictions of Susan B. Anthony": "تصنيف:تصوير ثقافي عن سوزان أنتوني",
    "Category:Cultural depictions of Su Shi": "تصنيف:تصوير ثقافي عن سو شي",
    "Category:Cultural depictions of Swedish monarchs": "تصنيف:تصوير ثقافي عن ملكيون سويديون",
    "Category:Cultural depictions of swimmers": "تصنيف:تصوير ثقافي عن سباحون",
    "Category:Cultural depictions of Sylvester Stallone": "تصنيف:تصوير ثقافي عن سيلفستر ستالون",
    "Category:Cultural depictions of Syngman Rhee": "تصنيف:تصوير ثقافي عن إي سنغ مان",
    "Category:Cultural depictions of table tennis players": "تصنيف:تصوير ثقافي عن لاعبو كرة طاولة",
    "Category:Cultural depictions of Tadeusz Kościuszko": "تصنيف:تصوير ثقافي عن تاديوش كوسيوسكو",
    "Category:Cultural depictions of Tecumseh": "تصنيف:تصوير ثقافي عن تيكومسيه",
    "Category:Cultural depictions of Ted Bundy": "تصنيف:تصوير ثقافي عن تيد بندي",
    "Category:Cultural depictions of T. E. Lawrence": "تصنيف:تصوير ثقافي عن توماس إدوارد لورنس",
    "Category:Cultural depictions of tennis players": "تصنيف:تصوير ثقافي عن لاعبو كرة مضرب",
    "Category:Cultural depictions of Teresa of Ávila": "تصنيف:تصوير ثقافي عن تيريزا الأفيلاوية",
    "Category:Cultural depictions of Thai monarchs": "تصنيف:تصوير ثقافي عن ملكيون تايلنديون",
    "Category:Cultural depictions of the 14th Dalai Lama": "تصنيف:تصوير ثقافي عن تينزن غياتسو",
    "Category:Cultural depictions of the assassination of Julius Caesar": "تصنيف:تصوير ثقافي عن اغتيال يوليوس قيصر",
    "Category:Cultural depictions of the Beach Boys": "تصنيف:تصوير ثقافي عن ذا بيتش بويز",
    "Category:Cultural depictions of the Harlem Globetrotters": "تصنيف:تصوير ثقافي عن هارلم غلوبتروترز",
    "Category:Cultural depictions of the Mafia": "تصنيف:تصوير ثقافي عن مافيا",
    "Category:Cultural depictions of Theodore Roosevelt": "تصنيف:تصوير ثقافي عن ثيودور روزفلت",
    "Category:Cultural depictions of Theseus": "تصنيف:تصوير ثقافي عن ثيسيوس",
    "Category:Cultural depictions of The Undertaker": "تصنيف:تصوير ثقافي عن أندرتيكر",
    "Category:Cultural depictions of the wives of Henry VIII": "تصنيف:تصوير ثقافي عن زوجات هنري الثامن ملك إنجلترا",
    "Category:Cultural depictions of the Wright brothers": "تصنيف:تصوير ثقافي عن الأخوان رايت",
    "Category:Cultural depictions of the Zodiac Killer": "تصنيف:تصوير ثقافي عن زودياك السفاح",
    "Category:Cultural depictions of Thomas Aquinas": "تصنيف:تصوير ثقافي عن توما الأكويني",
    "Category:Cultural depictions of Thomas Becket": "تصنيف:تصوير ثقافي عن توماس بيكيت",
    "Category:Cultural depictions of Thomas Carlyle": "تصنيف:تصوير ثقافي عن توماس كارليل",
    "Category:Cultural depictions of Thomas Edison": "تصنيف:تصوير ثقافي عن توماس إديسون",
    "Category:Cultural depictions of Thomas Jefferson": "تصنيف:تصوير ثقافي عن توماس جفرسون",
    "Category:Cultural depictions of Thomas Paine": "تصنيف:تصوير ثقافي عن توماس بين",
    "Category:Cultural depictions of Thomas the Apostle": "تصنيف:تصوير ثقافي عن توما",
    "Category:Cultural depictions of Tiberius": "تصنيف:تصوير ثقافي عن طيباريوس",
    "Category:Cultural depictions of Tiger Woods": "تصنيف:تصوير ثقافي عن تايغر وودز",
    "Category:Cultural depictions of Timur": "تصنيف:تصوير ثقافي عن تيمورلنك",
    "Category:Cultural depictions of Tina Turner": "تصنيف:تصوير ثقافي عن تينا ترنر",
    "Category:Cultural depictions of Titus": "تصنيف:تصوير ثقافي عن طيطوس",
    "Category:Cultural depictions of Tom Cruise": "تصنيف:تصوير ثقافي عن توم كروز",
    "Category:Cultural depictions of Tonya Harding": "تصنيف:تصوير ثقافي عن تونيا هاردينغ",
    "Category:Cultural depictions of Tony Blair": "تصنيف:تصوير ثقافي عن توني بلير",
    "Category:Cultural depictions of Tony Hawk": "تصنيف:تصوير ثقافي عن توني هوك",
    "Category:Cultural depictions of Torquato Tasso": "تصنيف:تصوير ثقافي عن توركواتو تاسو",
    "Category:Cultural depictions of Trajan": "تصنيف:تصوير ثقافي عن طريانوس",
    "Category:Cultural depictions of Trinidad and Tobago people": "تصنيف:تصوير ثقافي عن ترنيداديون",
    "Category:Cultural depictions of Truman Capote": "تصنيف:تصوير ثقافي عن ترومان كابوتي",
    "Category:Cultural depictions of T. S. Eliot": "تصنيف:تصوير ثقافي عن تي. إس. إليوت",
    "Category:Cultural depictions of Tupac Shakur": "تصنيف:تصوير ثقافي عن توباك شاكور",
    "Category:Cultural depictions of Turkish people": "تصنيف:تصوير ثقافي عن أتراك",
    "Category:Cultural depictions of Tutankhamun": "تصنيف:تصوير ثقافي عن توت عنخ آمون",
    "Category:Cultural depictions of Ulysses S. Grant": "تصنيف:تصوير ثقافي عن يوليسيس جرانت",
    "Category:Cultural depictions of Uzbekistani people": "تصنيف:تصوير ثقافي عن أوزبكستانيون",
    "Category:Cultural depictions of Valdemar IV of Denmark": "تصنيف:تصوير ثقافي عن فلاديمير الرابع ملك الدنمارك",
    "Category:Cultural depictions of Vallabhbhai Patel": "تصنيف:تصوير ثقافي عن ساردار فالاباي باتل",
    "Category:Cultural depictions of Victor Emmanuel II": "تصنيف:تصوير ثقافي عن فيتوريو إمانويلي الثاني",
    "Category:Cultural depictions of Victor Hugo": "تصنيف:تصوير ثقافي عن فكتور هيغو",
    "Category:Cultural depictions of Vincent van Gogh": "تصنيف:تصوير ثقافي عن فينسنت فان خوخ",
    "Category:Cultural depictions of Virgil": "تصنيف:تصوير ثقافي عن فيرجيل",
    "Category:Cultural depictions of Virginia Woolf": "تصنيف:تصوير ثقافي عن فرجينيا وولف",
    "Category:Cultural depictions of Vladimir Lenin": "تصنيف:تصوير ثقافي عن فلاديمير لينين",
    "Category:Cultural depictions of Vladimir Putin": "تصنيف:تصوير ثقافي عن فلاديمير بوتين",
    "Category:Cultural depictions of Vladimir the Great": "تصنيف:تصوير ثقافي عن فلاديمير الأول",
    "Category:Cultural depictions of Vlad the Impaler": "تصنيف:تصوير ثقافي عن فلاد الثالث المخوزق",
    "Category:Cultural depictions of Voltaire": "تصنيف:تصوير ثقافي عن فولتير",
    "Category:Cultural depictions of Walt Disney": "تصنيف:تصوير ثقافي عن والت ديزني",
    "Category:Cultural depictions of Walter Raleigh": "تصنيف:تصوير ثقافي عن والتر رالي",
    "Category:Cultural depictions of Walter Scott": "تصنيف:تصوير ثقافي عن والتر سكوت",
    "Category:Cultural depictions of Warren G. Harding": "تصنيف:تصوير ثقافي عن وارن جي. هاردينغ",
    "Category:Cultural depictions of Wayne Gretzky": "تصنيف:تصوير ثقافي عن واين جريتزكي",
    "Category:Cultural depictions of W. C. Fields": "تصنيف:تصوير ثقافي عن دبليو سي فيلدز",
    "Category:Cultural depictions of Wernher von Braun": "تصنيف:تصوير ثقافي عن فيرنر فون براون",
    "Category:Cultural depictions of Whitney Houston": "تصنيف:تصوير ثقافي عن ويتني هيوستن",
    "Category:Cultural depictions of WikiLeaks": "تصنيف:تصوير ثقافي عن ويكيليكس",
    "Category:Cultural depictions of Wilhelm II": "تصنيف:تصوير ثقافي عن فيلهلم الثاني",
    "Category:Cultural depictions of Wilhelmina of the Netherlands": "تصنيف:تصوير ثقافي عن فيلهلمينا ملكة هولندا",
    "Category:Cultural depictions of William Hogarth": "تصنيف:تصوير ثقافي عن وليم هوجرت",
    "Category:Cultural depictions of William Howard Taft": "تصنيف:تصوير ثقافي عن ويليام هوارد تافت",
    "Category:Cultural depictions of William III of England": "تصنيف:تصوير ثقافي عن ويليام الثالث ملك إنجلترا",
    "Category:Cultural depictions of William IV": "تصنيف:تصوير ثقافي عن ويليام الرابع ملك المملكة المتحدة",
    "Category:Cultural depictions of William Kidd": "تصنيف:تصوير ثقافي عن وليام كيد",
    "Category:Cultural depictions of William McKinley": "تصنيف:تصوير ثقافي عن ويليام ماكينلي",
    "Category:Cultural depictions of William Pitt the Younger": "تصنيف:تصوير ثقافي عن ويليام بيت الأصغر",
    "Category:Cultural depictions of William, Prince of Wales": "تصنيف:تصوير ثقافي عن ويليام أمير ويلز",
    "Category:Cultural depictions of William Randolph Hearst": "تصنيف:تصوير ثقافي عن ويليام راندولف هارست",
    "Category:Cultural depictions of William Shakespeare": "تصنيف:تصوير ثقافي عن وليم شكسبير",
    "Category:Cultural depictions of William the Conqueror": "تصنيف:تصوير ثقافي عن وليم الفاتح",
    "Category:Cultural depictions of William the Silent": "تصنيف:تصوير ثقافي عن ويليام الصامت",
    "Category:Cultural depictions of William Wallace": "تصنيف:تصوير ثقافي عن ويليام والاس",
    "Category:Cultural depictions of Winston Churchill": "تصنيف:تصوير ثقافي عن ونستون تشرشل",
    "Category:Cultural depictions of Wolfgang Amadeus Mozart": "تصنيف:تصوير ثقافي عن فولفغانغ أماديوس موتسارت",
    "Category:Cultural depictions of women": "تصنيف:تصوير ثقافي عن المرأة",
    "Category:Cultural depictions of Woodrow Wilson": "تصنيف:تصوير ثقافي عن وودرو ويلسون",
    "Category:Cultural depictions of Woody Allen": "تصنيف:تصوير ثقافي عن وودي آلن",
    "Category:Cultural depictions of Woody Guthrie": "تصنيف:تصوير ثقافي عن وودي ويلسون",
    "Category:Cultural depictions of wrestlers": "تصنيف:تصوير ثقافي عن مصارعون",
    "Category:Cultural depictions of writers": "تصنيف:تصوير ثقافي عن كتاب",
    "Category:Cultural depictions of Wu Zetian": "تصنيف:تصوير ثقافي عن وو شتيان",
    "Category:Cultural depictions of Xerxes I": "تصنيف:تصوير ثقافي عن خشايارشا الأول",
    "Category:Cultural depictions of Xi Jinping": "تصنيف:تصوير ثقافي عن شي جين بينغ",
    "Category:Cultural depictions of Yasser Arafat": "تصنيف:تصوير ثقافي عن ياسر عرفات",
    "Category:Cultural depictions of Yi Sun-sin": "تصنيف:تصوير ثقافي عن إي سن شن",
    "Category:Cultural depictions of Yoko Ono": "تصنيف:تصوير ثقافي عن يوكو أونو",
    "Category:Cultural depictions of Yuri Gagarin": "تصنيف:تصوير ثقافي عن يوري جاجارين",
    "Category:Cultural depictions of Zachary Taylor": "تصنيف:تصوير ثقافي عن زكاري تايلور",
    "Category:Cultural depictions of Zhou Enlai": "تصنيف:تصوير ثقافي عن تشو ان لاى",
    "Category:Cultural depictions of Zulfikar Ali Bhutto": "تصنيف:تصوير ثقافي عن ذو الفقار علي بوتو",
}

to_test = [
    # ("test_cultural_depictions_1", data1),
    ("test_cultural_depictions_fast", fast_data),
    ("test_cultural_depictions_slow", data_slow),
]


@pytest.mark.parametrize("category,expected", fast_data.items(), ids=fast_data.keys())
def test_cultural_depictions_fast(category: str, expected: str) -> None:
    """Test"""
    result = resolve_arabic_category_label(category)
    assert result == expected


@pytest.mark.parametrize("category,expected", data_slow.items(), ids=data_slow.keys())
def test_cultural_depictions_slow(category: str, expected: str) -> None:
    """Test"""
    result = resolve_arabic_category_label(category)
    assert result == expected


@pytest.mark.parametrize("name,data", to_test)
@pytest.mark.dump
def test_all_dump(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_arabic_category_label)

    dump_diff(diff_result, name)

    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"
